@@ -34,6 +34,8 @@ AudioOutputBase::AudioOutputBase(QString audiodevice, int,
     this->source = source;
     this->set_initial_vol = set_initial_vol;
     soundcard_buffer_size = 0;
+    buffer_output_data_for_use = false; // used by AudioOutputNULL
+
 
     src_ctx = NULL;
 
@@ -872,3 +874,10 @@ void *AudioOutputBase::kickoffOutputAudioLoop(void *player)
     return NULL;
 }
 
+int AudioOutputBase::readOutputData(unsigned char*, int)
+{
+    VERBOSE(VB_IMPORTANT, "base AudioOutputBase should not be "
+                          "getting asked to readOutputData()");
+    return 0;
+}
+
