@@ -675,6 +675,8 @@ static int JACK_bufsize (nframes_t nframes, void *arg)
  */
 int JACK_srate (nframes_t nframes, void *arg)
 {
+    (void)nframes; /* silence compiler warning */
+    (void)arg; /* silence compiler warning */
     TRACE("the sample rate is now %lu/sec\n", (long)nframes);
     return 0;
 }
@@ -864,13 +866,18 @@ static int JACK_OpenDevice(jack_driver_t* drv)
     }
 
     /* display a trace of the output ports we found */
-    for(i = 0; ports[i]; i++)
+    if(ports) {
+      for(i = 0; ports[i]; i++)
 	TRACE("ports[%d] = '%s'\n", i, ports[i]);
+    } else {
+      i = 0; // No ports found
+    }
 
     /* see if we have enough ports */
     if(i < drv->num_output_channels)
     {
       TRACE("ERR: jack_get_ports() failed to find ports with jack port flags of 0x%lX'\n", drv->jack_port_flags);
+      JACK_CloseDevice(drv, TRUE);
       return ERR_PORT_NOT_FOUND;
     }
 
@@ -893,13 +900,13 @@ static int JACK_OpenDevice(jack_driver_t* drv)
     {
       TRACE("jack_get_ports() portname %d of '%s\n", i, drv->jack_port_name[i]);
       ports = jack_get_ports(drv->client, drv->jack_port_name[i], NULL, drv->jack_port_flags);
-      TRACE("ports[%d] = '%s'\n", 0, ports[0]);      /* display a trace of the output port we found */
 
       if(!ports)
       {
           ERR("jack_get_ports() failed to find ports with jack port flags of 0x%lX'\n", drv->jack_port_flags);
           return ERR_PORT_NOT_FOUND;
       }
+      TRACE("ports[%d] = '%s'\n", 0, ports[0]);      /* display a trace of the output port we found */
 
       /* connect the port */
       TRACE("jack_connect() to port %d('%p')\n", i, drv->output_port[i]);
@@ -1195,7 +1202,7 @@ long JACK_Write(int deviceID, unsigned char *data, unsigned long bytes)
   /* check and see that we have enough space for this audio */
   bytes_free = JACK_GetBytesFreeSpaceFromDriver(drv);
   TRACE("bytes free == %ld\n", bytes_free);
-  if(bytes > bytes_free)
+  if((long)bytes > bytes_free)
   {
     bytes = 0; /* act as if we were told to write 0 bytes */
   }
@@ -1438,8 +1445,6 @@ long JACK_GetInputBytesPerSecond(int deviceID)
 /* NOTE: convert from output bytes to input bytes in here */
 static long JACK_GetBytesStoredFromDriver(jack_driver_t *drv)
 {
-  struct timeval now;
-  long elapsedMS;
   long return_val;
 
   /* get the number of bytes free space */
@@ -1625,6 +1630,7 @@ long JACK_GetBytesPerOutputFrame(int deviceID)
 long JACK_GetMaxBufferedBytes(int deviceID)
 {
   long return_val;
+  (void)deviceID; /* silence compiler warning */
 
   return_val = MAX_BUFFERED_BYTES;
   TRACE("getting MAX_BUFFERED_BYTES of %ld\n", return_val);
@@ -1635,8 +1641,9 @@ long JACK_GetMaxBufferedBytes(int deviceID)
 /* Set the max number of bytes the jack driver should buffer */
 void JACK_SetMaxBufferedBytes(int deviceID, long max_buffered_bytes)
 {
+  (void)deviceID; /* silence compiler warning */
   TRACE("setting MAX_BUFFERED_BYTES to %ld, from %ld\n", max_buffered_bytes, MAX_BUFFERED_BYTES);
-  MAX_BUFFERED_BYTES = max_buffered_bytes;
+  MAX_BUFFERED_BYTES = (unsigned long) max_buffered_bytes;
 }
 
 /* Get the number of output channels */
@@ -1661,6 +1668,8 @@ int JACK_GetNumInputChannels(int deviceID)
  
 int JACK_SetNumOutputChannels(int deviceID, int channels)
 {
+  (void)deviceID; /* silence compiler warning */
+  (void)channels; /* silence compiler warning */
   //FIXME: todo, should we resize buffers here by checking the size in JACK_callback() the next
   // time around??
   return 1;
