@@ -4,13 +4,13 @@
 #include <qvbox.h>
 #include <qapplication.h>
 #include <qlayout.h>
-#include <qobjectlist.h>
 #include <qdir.h>
 #include <qregexp.h>
 #include <qaccel.h>
 #include <qfocusdata.h>
 #include <qdict.h>
 #include <qsqldatabase.h>
+#include <qobjectlist.h> 
 
 #ifdef QWS
 #include <qwindowsystem_qws.h>
@@ -40,12 +40,13 @@ using namespace std;
 #include "lcddevice.h"
 #include "mythmediamonitor.h"
 #include "screensaver.h"
+#include "mythdbcon.h"
 
 #ifdef USE_LIRC
 static void *SpawnLirc(void *param)
 {
     MythMainWindow *main_window = (MythMainWindow *)param;
-    QString config_file = QDir::homeDirPath() + "/.mythtv/lircrc";
+    QString config_file = MythContext::GetConfDir() + "/lircrc";
     QString program("mythtv");
     LircClient *cl = new LircClient(main_window);
     if (!cl->Init(config_file, program))
@@ -59,7 +60,7 @@ static void *SpawnLirc(void *param)
 static void *SpawnJoystickMenu(void *param)
 {
     MythMainWindow *main_window = (MythMainWindow *)param;
-    QString config_file = QDir::homeDirPath() + "/.mythtv/joystickmenurc";
+    QString config_file = MythContext::GetConfDir() + "/joystickmenurc";
     JoystickMenuClient *js = new JoystickMenuClient(main_window);
     if (!js->Init(config_file))
         js->Process();
@@ -73,20 +74,20 @@ class KeyContext
   public:
     void AddMapping(int key, QString action)
     {
-        actionMap[key] = action;
+        actionMap[key].append(action);
     }
 
-    bool GetMapping(int key, QString &action)
+    bool GetMapping(int key, QStringList &actions)
     {
         if (actionMap.count(key) > 0)
         {
-            action = actionMap[key];
+            actions += actionMap[key];
             return true;
         }
         return false;
     }
 
-    QMap<int, QString> actionMap;
+    QMap<int, QStringList> actionMap;
 };
 
 struct JumpData
@@ -233,13 +234,10 @@ MythMainWindow::MythMainWindow(QWidget *parent, const char *name, bool modal,
     RegisterKey("Global", "7", "7", "7");
     RegisterKey("Global", "8", "8", "8");
     RegisterKey("Global", "9", "9", "9");
-
-    qApp->setOverrideCursor(QCursor(Qt::BlankCursor));
 }
 
 MythMainWindow::~MythMainWindow()
 {
-    qApp->restoreOverrideCursor();
     delete d;
 }
 
@@ -257,11 +255,12 @@ void MythMainWindow::Init(void)
     setFixedSize(QSize(d->screenwidth, d->screenheight));
 
     setFont(gContext->GetMediumFont());
-    setCursor(QCursor(Qt::BlankCursor));
 
+    bool hideCursor = gContext->GetNumSetting("HideMouseCursor", 1);
+    setCursor((hideCursor) ? (Qt::BlankCursor) : (Qt::ArrowCursor));
 #ifdef QWS
 #if QT_VERSION >= 0x030300
-    QWSServer::setCursorVisible(false);
+    QWSServer::setCursorVisible(!hideCursor);
 #endif
 #endif
 
@@ -406,7 +405,7 @@ void MythMainWindow::ExitToMainMenu(void)
 bool MythMainWindow::TranslateKeyPress(const QString &context,
                                        QKeyEvent *e, QStringList &actions)
 {
-    actions = QStringList();
+    actions.clear();
     int keynum = d->TranslateKeyNum(e);
 
     if (d->jumpMap.count(keynum) > 0 && d->exitmenucallback == NULL)
@@ -419,24 +418,14 @@ bool MythMainWindow::TranslateKeyPress(const QString &context,
 
     bool retval = false;
 
-    QString action;
-
     if (d->keyContexts[context])
     {
-        action = "";
-        if (d->keyContexts[context]->GetMapping(keynum, action))
-        {
-            actions += action;
+        if (d->keyContexts[context]->GetMapping(keynum, actions))
             retval = true;
-        }
     }
 
-    action = "";
-    if (d->keyContexts["Global"]->GetMapping(keynum, action))
-    {
-        actions += action;
+    if (d->keyContexts["Global"]->GetMapping(keynum, actions))
         retval = true;
-    }
 
     return retval;
 }
@@ -446,22 +435,19 @@ void MythMainWindow::RegisterKey(const QString &context, const QString &action,
 {
     QString keybind = key;
 
-    QSqlDatabase *db = QSqlDatabase::database(QSqlDatabase::defaultConnection,
-                                              false);
-    if (db && db->isOpen())
+    MSqlQuery query(MSqlQuery::InitCon());
+    if (query.isConnected())
     {
-        QString thequery = QString("SELECT keylist FROM keybindings WHERE "
-                                   "context = \"%1\" AND action = \"%2\" AND "
-                                   "hostname = \"%2\";")
-                                  .arg(context).arg(action)
-                                  .arg(gContext->GetHostName());
+        query.prepare("SELECT keylist FROM keybindings WHERE "
+                      "context = :CONTEXT AND action = :ACTION AND "
+                      "hostname = :HOSTNAME ;");
+        query.bindValue(":CONTEXT", context);
+        query.bindValue(":ACTION", action);
+        query.bindValue(":HOSTNAME", gContext->GetHostName());
     
-        QSqlQuery query = db->exec(thequery);
-    
-        if (query.isActive() && query.numRowsAffected() > 0)
+        if (query.exec() && query.isActive() && query.size() > 0)
         {
             query.next();
-    
             keybind = query.value(0).toString();
         }
         else
@@ -470,18 +456,24 @@ void MythMainWindow::RegisterKey(const QString &context, const QString &action,
             inskey.replace('\\', "\\\\");
             inskey.replace('\"', "\\\"");
     
-            thequery = QString("INSERT INTO keybindings (context, action, "
-                               "description, keylist, hostname) VALUES "
-                               "(\"%1\", \"%2\", \"%3\", \"%4\", \"%5\");")
-                               .arg(context).arg(action).arg(description)
-                               .arg(inskey).arg(gContext->GetHostName());
-    
-            query = db->exec(thequery);
-            if (!query.isActive())
+            query.prepare("INSERT INTO keybindings (context, action, "
+                          "description, keylist, hostname) VALUES "
+                          "( :CONTEXT, :ACTION, :DESCRIPTION, :KEYLIST, "
+                          ":HOSTNAME );");
+            query.bindValue(":CONTEXT", context);
+            query.bindValue(":ACTION", action);
+            query.bindValue(":DESCRIPTION", description);
+            query.bindValue(":KEYLIST", inskey);
+            query.bindValue(":HOSTNAME", gContext->GetHostName());
+
+            if (!query.exec() || !query.isActive())
+            {
                 MythContext::DBError("Insert Keybinding", query);
+            }
         }
     }
 
+
     QKeySequence keyseq(keybind);
 
     if (!d->keyContexts[context])
@@ -492,20 +484,19 @@ void MythMainWindow::RegisterKey(const QString &context, const QString &action,
         int keynum = keyseq[i];
         keynum &= ~Qt::UNICODE_ACCEL;
 
-        QString dummyaction = "";
+        QStringList dummyaction = "";
         if (d->keyContexts[context]->GetMapping(keynum, dummyaction))
         {
-            VERBOSE(VB_GENERAL, QString("Key %1 is already bound in context "
-                                        "%2.").arg(keybind).arg(context));
-        }
-        else
-        {
-            d->keyContexts[context]->AddMapping(keynum, action);
-            //VERBOSE(VB_GENERAL, QString("Binding: %1 to action: %2 (%3)")
-            //                           .arg(key).arg(action)
-            //                           .arg(context));
+            VERBOSE(VB_GENERAL, QString("Key %1 is bound to multiple actions "
+                                        "in context %2.")
+                    .arg(keybind).arg(context));
         }
 
+        d->keyContexts[context]->AddMapping(keynum, action);
+        //VERBOSE(VB_GENERAL, QString("Binding: %1 to action: %2 (%3)")
+        //                           .arg(key).arg(action)
+        //                           .arg(context));
+
         if (action == "ESCAPE" && context == "Global" && i == 0)
             d->escapekey = keynum;
     }
@@ -517,20 +508,17 @@ void MythMainWindow::RegisterJump(const QString &destination,
 {
     QString keybind = key;
 
-    QSqlDatabase *db = QSqlDatabase::database(QSqlDatabase::defaultConnection,
-                                              false);
-    if (db && db->isOpen())
+    MSqlQuery query(MSqlQuery::InitCon());
+    if (query.isConnected())
     {
-        QString thequery = QString("SELECT keylist FROM jumppoints WHERE "
-                                   "destination = \"%1\" and hostname = \"%2\";")
-                                  .arg(destination).arg(gContext->GetHostName());
+        query.prepare("SELECT keylist FROM jumppoints WHERE "
+                      "destination = :DEST and hostname = :HOST ;");
+        query.bindValue(":DEST", destination);
+        query.bindValue(":HOST", gContext->GetHostName());
     
-        QSqlQuery query = db->exec(thequery);
-    
-        if (query.isActive() && query.numRowsAffected() > 0)
+        if (query.exec() && query.isActive() && query.size() > 0)
         {
             query.next();
-     
             keybind = query.value(0).toString();
         }
         else
@@ -539,18 +527,22 @@ void MythMainWindow::RegisterJump(const QString &destination,
             inskey.replace('\\', "\\\\");
             inskey.replace('\"', "\\\"");
     
-            thequery = QString("INSERT INTO jumppoints (destination, description, "
-                               "keylist, hostname) VALUES (\"%1\", \"%2\", \"%3\", "
-                               "\"%4\");").arg(destination).arg(description)
-                                          .arg(inskey)
-                                          .arg(gContext->GetHostName());
-    
-            query = db->exec(thequery);
-            if (!query.isActive())
+            query.prepare("INSERT INTO jumppoints (destination, description, "
+                          "keylist, hostname) VALUES ( :DEST, :DESC, :KEYLIST, "
+                          ":HOST );");
+            query.bindValue(":DEST", destination);
+            query.bindValue(":DEDC", description);
+            query.bindValue(":KEYLIST", inskey);
+            query.bindValue(":HOST", gContext->GetHostName());
+
+            if (!query.exec() || !query.isActive())
+            { 
                 MythContext::DBError("Insert Jump Point", query);
+            } 
         }
     }
-   
+
+
     JumpData jd = { callback, destination, description };
     d->destinationMap[destination] = jd;
  
@@ -881,7 +873,6 @@ MythDialog::MythDialog(MythMainWindow *parent, const char *name, bool setsize)
     defaultSmallFont = gContext->GetSmallFont();
 
     setFont(defaultMediumFont);
-    setCursor(QCursor(Qt::BlankCursor));
 
     if (setsize)
     {
@@ -1036,7 +1027,6 @@ MythPopupBox::MythPopupBox(MythMainWindow *parent, const char *name)
     setPalette(parent->palette());
     popupForegroundColor = foregroundColor ();
     setFont(parent->font());
-    setCursor(QCursor(Qt::BlankCursor));
 
     hpadding = gContext->GetNumSetting("PopupHeightPadding", 120);
     wpadding = gContext->GetNumSetting("PopupWidthPadding", 80);
@@ -1065,7 +1055,6 @@ MythPopupBox::MythPopupBox(MythMainWindow *parent, bool graphicPopup,
     setFrameStyle(QFrame::Box | QFrame::Plain);
     setPalette(parent->palette());
     setFont(parent->font());
-    setCursor(QCursor(Qt::BlankCursor));
 
     hpadding = gContext->GetNumSetting("PopupHeightPadding", 120);
     wpadding = gContext->GetNumSetting("PopupWidthPadding", 80);
@@ -1103,7 +1092,7 @@ bool MythPopupBox::focusNextPrevChild(bool next)
         }
 
         w = (next) ? focusList->prev() : focusList->next();
-    }
+    }   
     while (w && !(candidate && w == startingPoint) && (countdown-- > 0));
 
     if (!candidate)
@@ -1407,7 +1396,6 @@ MythProgressDialog::MythProgressDialog(const QString &message, int totalSteps)
     gContext->GetScreenSettings(screenwidth, wmult, screenheight, hmult);
 
     setFont(gContext->GetMediumFont());
-    setCursor(QCursor(Qt::BlankCursor));
 
     gContext->ThemeWidget(this);
 
