@@ -27,6 +27,8 @@
 
 #include "mythcontext.h"
 #include "mythwizard.h"
+#include "mythdbcon.h"
+#include "DisplayRes.h"
 
 QWidget* Configurable::configWidget(ConfigurationGroup *cg, QWidget* parent,
                                     const char* widgetName) 
@@ -58,18 +60,18 @@ Setting* ConfigurationGroup::byName(QString name) {
     return NULL;
 }
 
-void ConfigurationGroup::load(QSqlDatabase* db) {
+void ConfigurationGroup::load() {
     for(childList::iterator i = children.begin() ;
         i != children.end() ;
         ++i )
-        (*i)->load(db);
+        (*i)->load();
 }
 
-void ConfigurationGroup::save(QSqlDatabase* db) {
+void ConfigurationGroup::save() {
     for(childList::iterator i = children.begin() ;
         i != children.end() ;
         ++i )
-        (*i)->save(db);
+        (*i)->save();
 }
 
 QWidget* VerticalConfigurationGroup::configWidget(ConfigurationGroup *cg, 
@@ -90,13 +92,28 @@ QWidget* VerticalConfigurationGroup::configWidget(ConfigurationGroup *cg,
 
     if (uselabel)
     {
-        layout = new QVBoxLayout(widget, (int)(28 * hmult));
+        int space = -1;
+        int margin = (int)(28 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+
+        layout = new QVBoxLayout(widget, margin, space);
         // This makes weird and bad things happen in qt -mdz 2002/12/28
         //widget->setInsideMargin(20);
         widget->setTitle(getLabel());
     }
     else
-        layout = new QVBoxLayout(widget, (int)(10 * hmult));
+    {
+        int space = -1;
+        int margin = (int)(10 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+        layout = new QVBoxLayout(widget, margin, space);
+    }
 
     for(unsigned i = 0 ; i < children.size() ; ++i)
         if (children[i]->isVisible())
@@ -133,13 +150,29 @@ QWidget* HorizontalConfigurationGroup::configWidget(ConfigurationGroup *cg,
 
     if (uselabel)
     {
-        layout = new QHBoxLayout(widget, (int)(28 * hmult));
+        int space = -1;
+        int margin = (int)(28 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+
+        layout = new QHBoxLayout(widget, margin, space);
         // This makes weird and bad things happen in qt -mdz 2002/12/28
         //widget->setInsideMargin(20);
         widget->setTitle(getLabel());
     }
     else
-        layout = new QHBoxLayout(widget, (int)(10 * hmult));
+    {
+        int space = -1;
+        int margin = (int)(10 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+
+        layout = new QHBoxLayout(widget, margin, space);
+    }
 
     for(unsigned i = 0 ; i < children.size() ; ++i)
         if (children[i]->isVisible())
@@ -158,6 +191,66 @@ QWidget* HorizontalConfigurationGroup::configWidget(ConfigurationGroup *cg,
     return widget;
 }
 
+QWidget* GridConfigurationGroup::configWidget(ConfigurationGroup *cg, 
+                                              QWidget* parent, 
+                                              const char* widgetName)
+{
+    QGroupBox* widget = new QGroupBox(parent, widgetName);
+    widget->setBackgroundOrigin(QWidget::WindowOrigin);
+
+    if (!useframe)
+        widget->setFrameShape(QFrame::NoFrame);
+
+    QGridLayout *layout = NULL;
+
+    float wmult = 0, hmult = 0;
+
+    gContext->GetScreenSettings(wmult, hmult);
+
+    int rows = (children.size()+columns-1) / columns;
+    if (uselabel)
+    {
+        int space = -1;
+        int margin = (int)(28 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+
+        layout = new QGridLayout(widget, rows, columns, margin, space);
+        // This makes weird and bad things happen in qt -mdz 2002/12/28
+        //widget->setInsideMargin(20);
+        widget->setTitle(getLabel());
+    }
+    else
+    {
+        int space = -1;
+        int margin = (int)(10 * hmult);
+        if (zeroSpace)
+            space = 4;
+        if (zeroMargin)
+            margin = 4;
+
+        layout = new QGridLayout(widget, rows, columns, margin, space);
+    }
+
+    for (unsigned i = 0 ; i < children.size() ; ++i)
+        if (children[i]->isVisible())
+        {
+            QWidget *child = children[i]->configWidget(cg, widget, NULL);
+            layout->addWidget(child, i / columns, i % columns);
+            children[i]->setEnabled(children[i]->isEnabled());
+        }
+
+    if (cg)
+    {
+        connect(this, SIGNAL(changeHelpText(QString)), cg,
+                SIGNAL(changeHelpText(QString)));
+    }
+
+    return widget;
+}
+
 QWidget* StackedConfigurationGroup::configWidget(ConfigurationGroup *cg, 
                                                  QWidget* parent,
                                                  const char* widgetName) 
@@ -215,11 +308,11 @@ void StackedConfigurationGroup::raise(Configurable* child) {
     cout << "BUG: StackedConfigurationGroup::raise(): unrecognized child " << child << " on setting " << getName() << '/' << getLabel() << endl;
 }
 
-void StackedConfigurationGroup::save(QSqlDatabase* db) {
+void StackedConfigurationGroup::save() {
     if (saveAll)
-        ConfigurationGroup::save(db);
+        ConfigurationGroup::save();
     else if (top < children.size())
-        children[top]->save(db);
+        children[top]->save();
 }
 
 void TriggeredConfigurationGroup::setTrigger(Configurable* _trigger) {
@@ -538,6 +631,9 @@ QWidget* ComboBoxSetting::configWidget(ConfigurationGroup *cg, QWidget* parent,
     if (isSet)
         widget->setCurrentItem(current);
 
+    if (1 < step)
+        widget->setStep(step);
+
     if (rw)
         connect(widget, SIGNAL(highlighted(const QString &)),
                 this, SLOT(setValue(const QString &)));
@@ -577,6 +673,49 @@ void ComboBoxSetting::setVisible(bool b)
     }
 }
 
+void HostRefreshRateComboBox::ChangeResolution(const QString& resolution)
+{
+    clearSelections();
+    
+    const vector<short> list = GetRefreshRates(resolution);
+    addSelection(QObject::tr("Any"), "0");
+    int hz50 = -1, hz60 = -1;
+    for (uint i=0; i<list.size(); ++i)
+    {        
+        QString sel = QString::number(list[i]);
+        addSelection(sel+" Hz", sel);
+        hz50 = (50 == list[i]) ? i : hz50;
+        hz60 = (60 == list[i]) ? i : hz60;
+    }
+    
+    setValue(0);
+    if ("640x480" == resolution || "720x480" == resolution)
+        setValue(hz60+1);
+    if ("640x576" == resolution || "720x576" == resolution)
+        setValue(hz50+1);
+    
+    setEnabled(list.size());
+}
+
+const vector<short> HostRefreshRateComboBox::GetRefreshRates(const QString &res)
+{
+    QStringList slist = QStringList::split("x", res);
+    int w = 0, h = 0;
+    bool ok0 = false, ok1 = false;
+    if (2 == slist.size())
+    {
+        w = slist[0].toInt(&ok0);
+        h = slist[1].toInt(&ok1);
+    }
+
+    DisplayRes *display_res = DisplayRes::GetDisplayRes();
+    if (display_res && ok0 && ok1)
+        return display_res->GetRefreshRates(w, h);    
+
+    vector<short> list;
+    return list;
+}
+
 void PathSetting::addSelection(const QString& label,
                                QString value,
                                bool select) {
@@ -713,10 +852,10 @@ MythDialog* ConfigurationDialog::dialogWidget(MythMainWindow *parent,
     return dialog;
 }
 
-int ConfigurationDialog::exec(QSqlDatabase* db, bool saveOnAccept, bool doLoad) 
+int ConfigurationDialog::exec(bool saveOnAccept, bool doLoad) 
 {
     if (doLoad)
-        load(db);
+        load();
 
     MythDialog* dialog = dialogWidget(gContext->GetMainWindow());
     dialog->Show();
@@ -724,7 +863,7 @@ int ConfigurationDialog::exec(QSqlDatabase* db, bool saveOnAccept, bool doLoad)
     int ret;
 
     if ((ret = dialog->exec()) == QDialog::Accepted && saveOnAccept)
-        save(db);
+        save();
 
     delete dialog;
 
@@ -754,64 +893,81 @@ MythDialog* ConfigurationWizard::dialogWidget(MythMainWindow *parent,
     return wizard;
 }
 
-void SimpleDBStorage::load(QSqlDatabase* db) {
+void SimpleDBStorage::load() 
+{
     QString querystr = QString("SELECT %1 FROM %2 WHERE %3;")
         .arg(column).arg(table).arg(whereClause());
-    QSqlQuery query = db->exec(querystr);
+    
+    MSqlQuery query(MSqlQuery::InitCon());
+    query.exec(querystr);
 
-    if (query.isActive() && query.numRowsAffected() > 0) {
+    if (query.isActive() && query.size() > 0) 
+    {
         query.next();
         QString result = query.value(0).toString();
-        if (result != QString::null) {
+        if (result != QString::null) 
+        {
           result = QString::fromUtf8(query.value(0).toString());
           setValue(result);
           setUnchanged();
         }
-   }
- }
+    }
+}
 
-void SimpleDBStorage::save(QSqlDatabase* db) {
+void SimpleDBStorage::save() 
+{
     if (!isChanged())
         return;
 
     QString querystr = QString("SELECT * FROM %1 WHERE %2;")
         .arg(table).arg(whereClause());
-    QSqlQuery query = db->exec(querystr);
 
-    if (query.isActive() && query.numRowsAffected() > 0) {
+    MSqlQuery query(MSqlQuery::InitCon());
+    query.exec(querystr);
+
+    if (query.isActive() && query.size() > 0) {
         // Row already exists
-        querystr = QString("UPDATE %1 SET %2 WHERE %3;")
-            .arg(table).arg(setClause()).arg(whereClause());
-        query = db->exec(querystr);
+        // Don"t change this QString. See the CVS logs rev 1.91.
+        querystr = QString("UPDATE " + table + " SET " + setClause() + 
+                           " WHERE " + whereClause() + ";");
+        // cerr << querystr << endl;
+        query.exec(querystr);
         if (!query.isActive())
             MythContext::DBError("simpledbstorage update", querystr);
     } else {
         // Row does not exist yet
         querystr = QString("INSERT INTO %1 SET %2;")
             .arg(table).arg(setClause());
-        query = db->exec(querystr);
+        query.exec(querystr);
         if (!query.isActive())
             MythContext::DBError("simpledbstorage update", querystr);
     }
 }
 
-void AutoIncrementStorage::save(QSqlDatabase* db) {
-    if (intValue() == 0) {
+void AutoIncrementStorage::save() {
+    if (intValue() == 0) 
+    {
         // Generate a new, unique ID
-        QString query = QString("INSERT INTO %1 (%2) VALUES (0);").arg(table).arg(column);
-        QSqlQuery result = db->exec(query);
-        if (!result.isActive() || result.numRowsAffected() < 1) {
-            MythContext::DBError("inserting row", result);
+        QString querystr = QString("INSERT INTO %1 (%2) VALUES (0);")
+                                .arg(table).arg(column);
+
+        MSqlQuery query(MSqlQuery::InitCon());
+        query.exec(querystr);
+
+        if (!query.isActive() || query.numRowsAffected() < 1) 
+        {
+            MythContext::DBError("inserting row", query);
             return;
         }
-        result = db->exec("SELECT LAST_INSERT_ID();");
-        if (!result.isActive() || result.numRowsAffected() < 1) {
-            MythContext::DBError("selecting last insert id", result);
+        query.exec("SELECT LAST_INSERT_ID();");
+        if (!query.isActive() || query.size() < 1) 
+        {
+            MythContext::DBError("selecting last insert id", query);
             return;
         }
 
-        result.next();
-        setValue(result.value(0).toInt());
+        query.next();
+        setValue(query.value(0).toInt());
     }
 }
 
@@ -995,17 +1151,18 @@ HostnameSetting::HostnameSetting(void)  {
     setValue(gContext->GetHostName());
 }
 
-void ChannelSetting::fillSelections(QSqlDatabase* db, SelectSetting* setting) {
+void ChannelSetting::fillSelections(SelectSetting* setting) {
 
     // this should go somewhere else, in something that knows about
     // channels and how they're stored in the database.  We're just a
     // selector.
 
-    QSqlQuery result = db->exec("SELECT name, chanid FROM channel;");
-    if (result.isActive() && result.numRowsAffected() > 0)
-        while (result.next())
-            setting->addSelection(result.value(0).toString(),
-                                  QString::number(result.value(1).toInt()));
+    MSqlQuery query(MSqlQuery::InitCon()); 
+    query.prepare("SELECT name, chanid FROM channel;");
+    if (query.exec() && query.isActive() && query.size() > 0)
+        while (query.next())
+            setting->addSelection(query.value(0).toString(),
+                                  QString::number(query.value(1).toInt()));
 }
 
 QWidget* ButtonSetting::configWidget(ConfigurationGroup* cg, QWidget* parent,
@@ -1094,9 +1251,9 @@ MythDialog* ConfigurationPopupDialog::dialogWidget(MythMainWindow* parent,
     return dialog;
 }
 
-int ConfigurationPopupDialog::exec(QSqlDatabase* db, bool saveOnAccept)
+int ConfigurationPopupDialog::exec(bool saveOnAccept)
 {
-    load(db);
+    load();
 
     dialog = (ConfigPopupDialogWidget*)dialogWidget(gContext->GetMainWindow());
     dialog->ShowPopup(this);
@@ -1104,7 +1261,7 @@ int ConfigurationPopupDialog::exec(QSqlDatabase* db, bool saveOnAccept)
     int ret;
 
     if ((ret = dialog->exec()) == QDialog::Accepted && saveOnAccept)
-        save(db);
+        save();
 
     return ret;
 }
