@@ -26,13 +26,6 @@ using namespace std;
 #include "util.h"
 #include "mythcontext.h"
 
-#if defined(Q_WS_X11)
-extern "C" {
-#include <X11/Xlib.h>
-#include <X11/extensions/Xinerama.h>
-}
-#endif
-
 #include <qimage.h>
 #include <qpainter.h>
 #include <qpixmap.h>
@@ -222,6 +215,17 @@ bool ReadStringList(QSocketDevice *socket, QStringList &list, bool quickTimeout)
     sizestr = sizestr.stripWhiteSpace();
     int btr = sizestr.toInt();
 
+    if (btr < 1)
+    {
+        int pending = socket->bytesAvailable();
+        QCString dump(pending + 1);
+        socket->readBlock(dump.data(), pending);
+        VERBOSE(VB_IMPORTANT, QString("Protocol error: '%1' is not a valid "
+                                      "size prefix. %2 bytes pending.")
+                                      .arg(sizestr).arg(pending));
+        return false;
+    }
+
     QCString utf8(btr + 1);
 
     int read = 0;
@@ -373,9 +377,9 @@ bool WriteStringList(QSocket *socket, QStringList &list)
     {
         QString msg = payload;
 
-        if (msg.length() > 58)
+        if (msg.length() > 53)
         {
-            msg.truncate(55);
+            msg.truncate(50);
             msg += "...";
         }
         VERBOSE(VB_NETWORK, msg);
@@ -453,6 +457,17 @@ bool ReadStringList(QSocket *socket, QStringList &list)
     sizestr = sizestr.stripWhiteSpace();
     int size = sizestr.toInt();
 
+    if (size < 1)
+    {
+        int pending = socket->bytesAvailable();
+        QCString dump(pending + 1);
+        socket->readBlock(dump.data(), pending);
+        VERBOSE(VB_IMPORTANT, QString("Protocol error: '%1' is not a valid "
+                                      "size prefix. %2 bytes pending.")
+                                      .arg(sizestr).arg(pending));
+        return false;
+    }
+
     QCString utf8(size + 1);
 
     int read = 0;
@@ -463,6 +478,13 @@ bool ReadStringList(QSocket *socket, QStringList &list)
         qApp->lock();
         int temp = socket->readBlock(utf8.data() + read, size);
         qApp->unlock();
+
+        if (temp < 0)
+        {
+            VERBOSE(VB_IMPORTANT, "ReadStringList failed.  Bailing..\n");
+            return false;
+        }
+
         // cerr << "  read: " << temp << endl; //DEBUG
         read += temp;
         size -= temp;
@@ -589,55 +611,6 @@ long long decodeLongLong(QStringList &list, QStringList::iterator &it)
     return retval;
 } 
 
-#if defined(Q_WS_X11)
-void GetMythTVGeometry(Display *dpy, int screen_num, int *x, int *y, 
-                       int *w, int *h) 
-{
-    int event_base, error_base;
-
-    if (XineramaQueryExtension(dpy, &event_base, &error_base) &&
-        XineramaIsActive(dpy)) 
-    {
-        XineramaScreenInfo *xinerama_screens;
-        XineramaScreenInfo *screen;
-        int nr_xinerama_screens;
-
-        int screen_nr = gContext->GetNumSetting("XineramaScreen", 0);
-
-        xinerama_screens = XineramaQueryScreens(dpy, &nr_xinerama_screens);
-
-        printf("Found %d Xinerama Screens.\n", nr_xinerama_screens);
-
-        if (screen_nr > 0 && screen_nr < nr_xinerama_screens)
-        {
-            screen = &xinerama_screens[screen_nr];
-            printf("Using screen %d, %dx%d+%d+%d\n",
-                   screen_nr, screen->width, screen->height, screen->x_org, 
-                   screen->y_org );
-        } 
-        else 
-        {
-            screen = &xinerama_screens[0];
-            printf("Using first Xinerama screen, %dx%d+%d+%d\n",
-                   screen->width, screen->height, screen->x_org, screen->y_org);
-        }
-
-        *w = screen->width;
-        *h = screen->height;
-        *x = screen->x_org;
-        *y = screen->y_org;
-
-        XFree(xinerama_screens);
-    } 
-    else 
-    {
-        *w = DisplayWidth(dpy, screen_num);
-        *h = DisplayHeight(dpy, screen_num);
-        *x = 0; *y = 0;
-    }
-}
-#endif
-
 QRgb blendColors(QRgb source, QRgb add, int alpha)
 {
     int sred = qRed(source);
@@ -742,6 +715,23 @@ QString cutDownString(QString text, QFont *testFont, int maxwidth)
     return text;
 }
 
+int MythSecsTo(const QDateTime &from, const QDateTime &to)
+{
+   return (from.time().secsTo(to.time()) +
+           from.date().daysTo(to.date()) * 60 * 60 * 24);
+}
+
+QDateTime MythUTCToLocal(const QDateTime &utc)
+{
+    QDateTime local = QDateTime(QDate(1970, 1, 1));
+
+    int timesecs = MythSecsTo(local, utc);
+    QDateTime localdt;
+    localdt.setTime_t(timesecs);
+
+    return localdt;
+}
+    
 long long stringToLongLong(const QString &str)
 {
     long long retval = 0;
@@ -834,10 +824,10 @@ bool getMemStats(int &totalMB, int &freeMB, int &totalVM, int &freeVM)
         return false;
     }
     else
-        totalMB = sinfo.totalram/MB,
-        freeMB  = sinfo.freeram/MB,
-        totalVM = sinfo.totalswap/MB,
-        freeVM  = sinfo.freeswap/MB;
+        totalMB = (sinfo.totalram  * sinfo.mem_unit)/MB,
+        freeMB  = (sinfo.freeram   * sinfo.mem_unit)/MB,
+        totalVM = (sinfo.totalswap * sinfo.mem_unit)/MB,
+        freeVM  = (sinfo.freeswap  * sinfo.mem_unit)/MB;
 
 #elif defined(CONFIG_DARWIN)
     mach_port_t             mp;
