@@ -1,5 +1,6 @@
 #include <qapplication.h>
 #include <qdatetime.h>
+#include <qfileinfo.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -422,9 +423,26 @@ RingBuffer::RingBuffer(const QString &lfilename, bool write, bool usereadahead)
                     }
                 }
             }
+
+            QFileInfo fileInfo(filename);
+            if (fileInfo.lastModified().secsTo(QDateTime::currentDateTime()) >
+                30 * 60)
+            {
+                oldfile = true;
+            }
         }
         else
+        {
             remotefile = new RemoteFile(filename);
+            if (!remotefile->isOpen())
+            {
+                VERBOSE(VB_IMPORTANT,
+                    QString("RingBuffer::RingBuffer(): Failed to open remote "
+                            "file (%1)").arg(filename));
+                delete remotefile;
+                remotefile = NULL;
+            }
+        }
 
         writemode = false;
     }
@@ -457,6 +475,14 @@ RingBuffer::RingBuffer(const QString &lfilename, long long size,
     else
     {
         remotefile = new RemoteFile(filename, recorder_num);
+        if (!remotefile->isOpen())
+        {
+            VERBOSE(VB_IMPORTANT,
+                    QString("RingBuffer::RingBuffer(): Failed to open remote "
+                            "file (%1)").arg(filename));
+            delete remotefile;
+            remotefile = NULL;
+        }
     }
 
     wrapcount = 0;
@@ -465,6 +491,7 @@ RingBuffer::RingBuffer(const QString &lfilename, long long size,
 
 void RingBuffer::Init(void)
 {
+    oldfile = false; 
     startreadahead = true;
 
     readaheadrunning = false;
@@ -587,7 +614,7 @@ int RingBuffer::safe_read(int fd, void *data, unsigned sz)
                 break;
 
             zerocnt++;
-            if (zerocnt >= 50) // 3 second timeout with usleep(60000)
+            if (zerocnt >= ((oldfile) ? 2 : 50)) // 3 second timeout with usleep(60000), or .12 if it's an old, unmodified file.
             {
                 break;
             }
@@ -951,14 +978,13 @@ int RingBuffer::ReadFromBuf(void *buf, int count)
     int avail = ReadBufAvail();
     readErr = 0;
     
-
     while (avail < count && !stopreads)
     {
         availWaitMutex.lock();
         wanttoread = count;
-        if (!availWait.wait(&availWaitMutex, 2000))
+        if (!availWait.wait(&availWaitMutex, 4000))
         {
-            VERBOSE(VB_IMPORTANT,"Waited 2 seconds for data to become available, waiting "
+            VERBOSE(VB_IMPORTANT,"Waited 4 seconds for data to become available, waiting "
                     "again...");
             readErr++;
             if (readErr > 7)
@@ -1250,7 +1276,17 @@ long long RingBuffer::Seek(long long pos, int whence)
         {
             if (whence == SEEK_SET)
             {
-                ret = lseek(fd2, pos, whence);
+                long long tmpPos = pos;
+                long long tmpRet;
+
+                if (tmpPos > filesize)
+                    tmpPos = tmpPos % filesize;
+
+                tmpRet = lseek(fd2, tmpPos, whence);
+                if (tmpRet == tmpPos)
+                    ret = pos;
+                else
+                    ret = tmpRet;
             }
             else if (whence == SEEK_CUR)
             {
@@ -1271,11 +1307,13 @@ long long RingBuffer::Seek(long long pos, int whence)
         {
             readpos += pos;
             totalreadpos += pos;
-            while (readpos > filesize)
-                readpos -= filesize;
-            while (readpos < 0)
-                readpos += filesize;
         }
+
+        while (readpos > filesize && filesize > 0)
+            readpos -= filesize;
+
+        while (readpos < 0 && filesize > 0)
+            readpos += filesize;
     }
 
     if (readaheadrunning)
