@@ -65,9 +65,6 @@ class ChannelBase
 
     virtual QString GetOrdering() { return channelorder; }
 
-    void SetDB(QSqlDatabase* _db_conn, pthread_mutex_t* _db_lock)
-        { db_conn = _db_conn; db_lock = _db_lock; };
-
   protected:
     TVRec *pParent;
     QString curchannelname;
@@ -81,9 +78,6 @@ class ChannelBase
 
     QString channelorder;
 
-    QSqlDatabase* db_conn;
-    pthread_mutex_t* db_lock;
-
     bool ChangeExternalChannel(const QString &newchan);
 };
 
