@@ -9,27 +9,30 @@ using namespace std;
 #include "mythcontext.h"
 #include "mythdbcon.h"
 
-const QString currentDatabaseVersion = "1071";
+const QString currentDatabaseVersion = "1083";
 
 static bool UpdateDBVersionNumber(const QString &newnumber);
 static bool performActualUpdate(const QString updates[], QString version,
                                 QString &dbver);
 static bool InitializeDatabase(void);
+bool doUpgradeTVDatabaseSchema(void);
 
 static bool UpdateDBVersionNumber(const QString &newnumber)
 {
-    QSqlDatabase *db_conn = QSqlDatabase::database();
-
     // delete old schema version
+    MSqlQuery query(MSqlQuery::InitCon());
+
     QString thequery = "DELETE FROM settings WHERE value='DBSchemaVer';";
-    db_conn->exec(thequery);
-    if (db_conn->lastError().type() != QSqlError::None)
+    query.prepare(thequery);
+    query.exec();
+
+    if (query.lastError().type() != QSqlError::None)
     {
         QString msg =
             QString("DB Error (Deleting old DB version number): \n"
                     "Query was: %1 \nError was: %2 \nnew version: %3")
             .arg(thequery)
-            .arg(MythContext::DBErrorMessage(db_conn->lastError()))
+            .arg(MythContext::DBErrorMessage(query.lastError()))
             .arg(newnumber);
         VERBOSE(VB_IMPORTANT, msg);
         return false;
@@ -38,14 +41,16 @@ static bool UpdateDBVersionNumber(const QString &newnumber)
     // set new schema version
     thequery = QString("INSERT INTO settings (value, data, hostname) "
                        "VALUES ('DBSchemaVer', %1, NULL);").arg(newnumber);
-    db_conn->exec(thequery);
-    if (db_conn->lastError().type() != QSqlError::None)
+    query.prepare(thequery);
+    query.exec();
+
+    if (query.lastError().type() != QSqlError::None)
     {
         QString msg =
             QString("DB Error (Setting new DB version number): \n"
                     "Query was: %1 \nError was: %2 \nnew version: %3")
             .arg(thequery)
-            .arg(MythContext::DBErrorMessage(db_conn->lastError()))
+            .arg(MythContext::DBErrorMessage(query.lastError()))
             .arg(newnumber);
         VERBOSE(VB_IMPORTANT, msg);
         return false;
@@ -57,7 +62,7 @@ static bool UpdateDBVersionNumber(const QString &newnumber)
 static bool performActualUpdate(const QString updates[], QString version,
                          QString &dbver)
 {
-    QSqlDatabase *db_conn = QSqlDatabase::database();
+    MSqlQuery query(MSqlQuery::InitCon());
 
     VERBOSE(VB_ALL, QString("Upgrading to schema version ") + version);
 
@@ -66,15 +71,16 @@ static bool performActualUpdate(const QString updates[], QString version,
 
     while (thequery != "")
     {
-        db_conn->exec(thequery);
+        query.prepare(thequery);
+        query.exec();
 
-        if (db_conn->lastError().type() != QSqlError::None)
+        if (query.lastError().type() != QSqlError::None)
         {
             QString msg =
                 QString("DB Error (Performing database upgrade): \n"
                         "Query was: %1 \nError was: %2 \nnew version: %3")
                 .arg(thequery)
-                .arg(MythContext::DBErrorMessage(db_conn->lastError()))
+                .arg(MythContext::DBErrorMessage(query.lastError()))
                 .arg(version);
             VERBOSE(VB_IMPORTANT, msg);
             return false;
@@ -95,6 +101,54 @@ bool UpgradeTVDatabaseSchema(void)
 {
     QString dbver = gContext->GetSetting("DBSchemaVer");
 
+    if (dbver == currentDatabaseVersion)
+        return true;
+
+    MSqlQuery lockquery(MSqlQuery::InitCon());
+
+    lockquery.prepare("CREATE TABLE IF NOT EXISTS "
+                      "schemalock ( schemalock int(1));");
+    if (!lockquery.exec())
+    {
+        VERBOSE(VB_IMPORTANT, QString("ERROR: Unable to create database "
+                                      "upgrade lock table: %1")
+                                      .arg(MythContext::DBErrorMessage(
+                                           lockquery.lastError())));
+        return false;
+    }
+
+    VERBOSE(VB_IMPORTANT, "Setting Lock for Database Schema upgrade. If you "
+                          "see a long pause here it means the Schema is "
+                          "already locked and is being upgraded by another "
+                          "Myth process.");
+
+    lockquery.prepare("LOCK TABLE schemalock WRITE;");
+    if (!lockquery.exec())
+    {
+        VERBOSE(VB_IMPORTANT, QString("ERROR: Unable to acquire database "
+                                      "upgrade lock")
+                                      .arg(MythContext::DBErrorMessage(
+                                           lockquery.lastError())));
+        return false;
+    }
+
+    bool ret = doUpgradeTVDatabaseSchema();
+
+    if (ret)
+        VERBOSE(VB_IMPORTANT, "Database Schema upgrade complete, unlocking.");
+    else
+        VERBOSE(VB_IMPORTANT, "Database Schema upgrade FAILED, unlocking.");
+
+    lockquery.prepare("UNLOCK TABLES;");
+    lockquery.exec();
+
+    return ret;
+}
+
+bool doUpgradeTVDatabaseSchema(void)
+{
+    QString dbver = gContext->GetSetting("DBSchemaVer");
+
     if (dbver == currentDatabaseVersion)
         return true;
     
@@ -547,24 +601,26 @@ bool UpgradeTVDatabaseSchema(void)
 
         VERBOSE(VB_ALL, QString("This could take a few minutes."));
 
-        QSqlDatabase *db = QSqlDatabase::database();
 
         QString thequery, chanid, startts;
-        QSqlQuery query;
         QDateTime recstartts;
 
+        MSqlQuery query(MSqlQuery::InitCon());
+
         thequery = QString("SELECT distinct recorded.chanid, "
                            "recorded.starttime "
                            "FROM recorded, recordedmarkup "
                            "WHERE recorded.chanid = recordedmarkup.chanid AND "
                            "recorded.starttime = recordedmarkup.starttime AND "
                            "(type = 4 OR type = 5) ");
-        query = db->exec(thequery);
+        query.prepare(thequery);
 
-        if (query.isActive() && query.numRowsAffected() > 0)
+        if (query.exec() && query.isActive() && query.size() > 0)
         {
+            MSqlQuery query2(MSqlQuery::InitCon());
             while (query.next())
             {
+
                 chanid  = query.value(0).toString();
                 recstartts = query.value(1).toDateTime();
                 startts = recstartts.toString("yyyyMMddhhmm");
@@ -574,8 +630,8 @@ bool UpgradeTVDatabaseSchema(void)
                                    "starttime = %2 WHERE chanid = '%1' AND "
                                    "starttime = '%3';").arg(chanid).arg(startts)
                                                        .arg(startts);
-
-                db->exec(thequery);
+                query2.prepare(thequery);
+                query2.exec();
             }  
         }
     }
@@ -1135,9 +1191,7 @@ QString("ALTER TABLE videosource ADD COLUMN freqtable VARCHAR(16) NOT NULL DEFAU
 
         if (gContext->GetNumSetting("AutoCommercialFlag", 1))
         {
-            QSqlDatabase *db = QSqlDatabase::database();
-
-            MSqlQuery query(QString::null, db);
+            MSqlQuery query(MSqlQuery::InitCon());
             query.prepare("UPDATE record SET autocommflag = 1;");
             query.exec();
         }
@@ -1399,21 +1453,213 @@ QString("ALTER TABLE videosource ADD COLUMN freqtable VARCHAR(16) NOT NULL DEFAU
             return false;
     }
 
+    if (dbver == "1071")
+    {
+        const QString updates[] = {
+"ALTER TABLE program ADD COLUMN manualid INT UNSIGNED NOT NULL DEFAULT 0;",
+"ALTER TABLE program DROP PRIMARY KEY;",
+"ALTER TABLE program ADD PRIMARY KEY (chanid, starttime, manualid);",
+"ALTER TABLE recordmatch ADD COLUMN manualid INT UNSIGNED;",
+""
+};
+        if (!performActualUpdate(updates, "1072", dbver))
+            return false;
+    }
+
+    if (dbver == "1072")
+    {
+        const QString updates[] = {
+"ALTER TABLE recorded ADD INDEX (title);",
+""
+};
+        if (!performActualUpdate(updates, "1073", dbver))
+            return false;
+    }
+
+    if (dbver == "1073")
+    {
+        const QString updates[] = {
+"ALTER TABLE capturecard ADD COLUMN firewire_connection INT UNSIGNED NOT NULL DEFAULT 0;",
+""
+};
+        if (!performActualUpdate(updates, "1074", dbver))
+            return false;
+    }
+
+    if (dbver == "1074")
+    {
+        const QString updates[] = {
+"INSERT INTO profilegroups SET name = \"USB Mpeg-4 Encoder (Plextor ConvertX, etc)\", cardtype = 'GO7007', is_default = 1;",
+"INSERT INTO recordingprofiles SET name = \"Default\", profilegroup = 8;",
+"INSERT INTO recordingprofiles SET name = \"Live TV\", profilegroup = 8;",
+"INSERT INTO recordingprofiles SET name = \"High Quality\", profilegroup = 8;",
+"INSERT INTO recordingprofiles SET name = \"Low Quality\", profilegroup = 8;",
+""
+};
+        if (!performActualUpdate(updates, "1075", dbver))
+            return false;
+    }
+
+    if (dbver == "1075")
+    {
+        const QString updates[] = {
+"CREATE TABLE IF NOT EXISTS recordedprogram ("
+"  chanid int(10) unsigned NOT NULL default '0',"
+"  starttime datetime NOT NULL default '0000-00-00 00:00:00',"
+"  endtime datetime NOT NULL default '0000-00-00 00:00:00',"
+"  title varchar(128) NOT NULL default '',"
+"  subtitle varchar(128) NOT NULL default '',"
+"  description text NOT NULL,"
+"  category varchar(64) NOT NULL default '',"
+"  category_type varchar(64) NOT NULL default '',"
+"  airdate year(4) NOT NULL default '0000',"
+"  stars float unsigned NOT NULL default '0',"
+"  previouslyshown tinyint(4) NOT NULL default '0',"
+"  title_pronounce varchar(128) NOT NULL default '',"
+"  stereo tinyint(1) NOT NULL default '0',"
+"  subtitled tinyint(1) NOT NULL default '0',"
+"  hdtv tinyint(1) NOT NULL default '0',"
+"  closecaptioned tinyint(1) NOT NULL default '0',"
+"  partnumber int(11) NOT NULL default '0',"
+"  parttotal int(11) NOT NULL default '0',"
+"  seriesid varchar(12) NOT NULL default '',"
+"  originalairdate date default NULL,"
+"  showtype varchar(30) NOT NULL default '',"
+"  colorcode varchar(20) NOT NULL default '',"
+"  syndicatedepisodenumber varchar(20) NOT NULL default '',"
+"  programid varchar(20) NOT NULL default '',"
+"  manualid int(10) unsigned NOT NULL default '0',"
+"  PRIMARY KEY  (chanid,starttime,manualid),"
+"  KEY endtime (endtime),"
+"  KEY title (title),"
+"  KEY title_pronounce (title_pronounce),"
+"  KEY seriesid (seriesid),"
+"  KEY programid (programid),"
+"  KEY id_start_end (chanid,starttime,endtime)"
+");",
+"CREATE TABLE IF NOT EXISTS recordedcredits ("
+"  person mediumint(8) unsigned NOT NULL default '0',"
+"  chanid int(10) unsigned NOT NULL default '0',"
+"  starttime datetime NOT NULL default '0000-00-00 00:00:00',"
+"  role set('actor','director','producer','executive_producer','writer','guest_star','host','adapter','presenter','commentator','guest') NOT NULL default '',"
+"  UNIQUE KEY chanid (chanid,starttime,person,role),"
+"  KEY person (person,role)"
+");",
+"CREATE TABLE IF NOT EXISTS recordedrating ("
+"  chanid int(10) unsigned NOT NULL default '0',"
+"  starttime datetime NOT NULL default '0000-00-00 00:00:00',"
+"  system char(8) NOT NULL default '',"
+"  rating char(8) NOT NULL default '',"
+"  UNIQUE KEY chanid (chanid,starttime,system,rating),"
+"  KEY starttime (starttime,system)"
+");",
+""
+       };
+       
+        if (!performActualUpdate(updates, "1076", dbver))
+            return false;
+    }
+
+    if (dbver == "1076")
+    {
+        const QString updates[] = {
+"ALTER TABLE channel MODIFY COLUMN serviceid mediumint unsigned;",
+""
+        }; 
+        if (!performActualUpdate(updates, "1077", dbver))
+            return false;
+    }
+
+    if (dbver == "1077")
+    {
+        const QString updates[] = {
+"INSERT INTO `dtv_privatetypes` "
+"(`sitype`,`networkid`,`private_type`,`private_value`) VALUES "
+"('dvb',40999,'parse_subtitle_list',"
+"'1070,1049,1041,1039,1038,1030,1016,1131,1068,1069');",
+""
+        }; 
+        if (!performActualUpdate(updates, "1078", dbver))
+            return false;
+    }
+
+    if (dbver == "1078")
+    {
+        const QString updates[] = {
+"ALTER TABLE capturecard ADD COLUMN dvb_hw_decoder INT DEFAULT '0';",
+""
+};
+        if (!performActualUpdate(updates, "1079", dbver))
+            return false;
+    }
+
+    if (dbver == "1079")
+    {
+        const QString updates[] = {
+"ALTER TABLE oldrecorded ADD COLUMN recordid INT NOT NULL DEFAULT 0;",
+""
+};
+        if (!performActualUpdate(updates, "1080", dbver))
+            return false;
+    }
+
+    if (dbver == "1080")
+    {
+        const QString updates[] = {
+"ALTER table recorded ADD INDEX (recordid);",
+"ALTER table oldrecorded ADD INDEX (recordid);",
+""
+};
+        if (!performActualUpdate(updates, "1081", dbver))
+            return false;
+    }
+
+    if (dbver == "1081")
+    {
+        const QString updates[] = {
+"CREATE TABLE IF NOT EXISTS oldfind ("
+"recordid INT NOT NULL DEFAULT 0,"
+"findid INT NOT NULL DEFAULT 0,"
+"PRIMARY KEY (recordid, findid)"
+");",
+"ALTER TABLE record ADD COLUMN parentid INT NOT NULL DEFAULT 0;",
+""
+};
+        if (!performActualUpdate(updates, "1082", dbver))
+            return false;
+    }
+
+    if (dbver == "1082")
+    {
+        const QString updates[] = {
+"CREATE TABLE IF NOT EXISTS videobookmarks ("
+"  filename varchar(255) NOT NULL,"
+"  bookmark varchar(128) default NULL,"
+"  PRIMARY KEY (filename)"
+");",
+""
+};
+        if (!performActualUpdate(updates, "1083", dbver))
+            return false;
+    }
+
     return true;
 }
 
 bool InitializeDatabase(void)
 {
-    QSqlDatabase *db_conn = QSqlDatabase::database();
-    QSqlQuery qQuery = db_conn->exec("SHOW TABLES;");
-    if (qQuery.isActive() && (qQuery.numRowsAffected() > 0))
+    MSqlQuery query(MSqlQuery::InitCon());
+    query.prepare("SHOW TABLES;");
+
+    // check for > 1 table here since the schemalock table should exist
+    if (query.exec() && query.isActive() && query.size() > 1)
     {
         QString msg = QString(
             "Told to create a NEW database schema, but the database\n"
             "already has %1 tables.\n"
             "If you are sure this is a good mythtv database, verify\n"
             "that the settings table has the DBSchemaVer variable.\n")
-            .arg(qQuery.numRowsAffected());
+            .arg(query.size() - 1);
         VERBOSE(VB_ALL, msg);
         return false;   
     }
