@@ -24,9 +24,8 @@ using namespace std;
 
 pthread_mutex_t avcodeclock = PTHREAD_MUTEX_INITIALIZER;
 
-NuppelDecoder::NuppelDecoder(NuppelVideoPlayer *parent, MythSqlDatabase *db,
-                             ProgramInfo *pginfo)
-    : DecoderBase(parent, db, pginfo),
+NuppelDecoder::NuppelDecoder(NuppelVideoPlayer *parent, ProgramInfo *pginfo)
+    : DecoderBase(parent, pginfo),
       gf(0), rtjd(0), video_width(0), video_height(0), video_size(0),
       video_frame_rate(0.0f), audio_samplerate(44100), 
 #ifdef WORDS_BIGENDIAN
@@ -192,9 +191,13 @@ int NuppelDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
         }
     }
 
+    if (fileheader.aspect > .999 && fileheader.aspect < 1.001)
+        fileheader.aspect = 4.0 / 3;
+    current_aspect = fileheader.aspect;
+
     m_parent->SetVideoParams(fileheader.width, fileheader.height,
                              fileheader.fps, fileheader.keyframedist,
-                             4.0 / 3, kScan_Detect);
+                             fileheader.aspect, kScan_Detect);
 
     video_width = fileheader.width;
     video_height = fileheader.height;
@@ -841,11 +844,16 @@ long NuppelDecoder::UpdateStoredFrameNum(long framenum)
     return 0;
 }
 
-void NuppelDecoder::WriteStoredData(RingBuffer *rb, bool storevid)
+void NuppelDecoder::WriteStoredData(RingBuffer *rb, bool storevid,
+                                    long timecodeOffset)
 {
     RawDataList *data;
     while(! StoredData.isEmpty()) {
         data = StoredData.first();
+
+        if (data->frameheader.frametype != 'S')
+            data->frameheader.timecode -= timecodeOffset;
+
         if (storevid || data->frameheader.frametype != 'V')
         {
             rb->Write(&(data->frameheader), FRAMEHEADERSIZE);
@@ -857,6 +865,16 @@ void NuppelDecoder::WriteStoredData(RingBuffer *rb, bool storevid)
     }
 }
 
+void NuppelDecoder::ClearStoredData()
+{
+    RawDataList *data;
+    while(!StoredData.isEmpty()) {
+        data = StoredData.first();
+        StoredData.removeFirst();
+        delete data;
+    }
+}
+
 // avignore = 0  : get audio and video
 //          = 1  : video only
 //          = -1 : neither, just parse
