@@ -26,8 +26,7 @@ using namespace std;
 
 #include "osdlistbtntype.h"
 
-OSD::OSD(int width, int height, int frint, const QString &font, 
-         const QString &ccfont, const QString &prefix, const QString &osdtheme,
+OSD::OSD(int width, int height, int frint,
          int dispx, int dispy, int dispw, int disph)
    : QObject()
 {
@@ -48,9 +47,6 @@ OSD::OSD(int width, int height, int frint, const QString &font,
 
     timeType = 0; 
     totalfadetime = 0;
-    fontname = font;
-    ccfontname = ccfont;
-    fontprefix = prefix;
 
     m_setsvisible = false;
     setList = NULL;
@@ -58,9 +54,8 @@ OSD::OSD(int width, int height, int frint, const QString &font,
     runningTreeMenu = NULL;
 
     setList = new vector<OSDSet *>;
-
-    fontSizeType = gContext->GetSetting("OSDThemeFontSizeType", "default");
     
+    QString osdtheme = gContext->GetSetting("OSDTheme");
     themepath = FindTheme(osdtheme);
 
     if (themepath == "")
@@ -130,7 +125,7 @@ void OSD::SetDefaults(void)
         QString name = "cc_font";
         int fontsize = 480 / 27;
 
-        ccfont = LoadFont(ccfontname, fontsize);
+        ccfont = LoadFont(gContext->GetSetting("OSDCCFont"), fontsize);
 
         if (ccfont)
             fontMap[name] = ccfont;
@@ -181,7 +176,7 @@ void OSD::SetDefaults(void)
 
         if (!actfont)
         {
-            actfont = LoadFont(fontname, 16);
+            actfont = LoadFont(gContext->GetSetting("OSDFont"), 16);
 
             if (actfont)
                 fontMap["treemenulistfont"] = actfont;
@@ -246,13 +241,13 @@ void OSD::Reinit(int width, int height, int frint, int dispx, int dispy,
 
 QString OSD::FindTheme(QString name)
 {
-    QString testdir = QDir::homeDirPath() + "/.mythtv/osd/" + name;
+    QString testdir = MythContext::GetConfDir() + "/osd/" + name;
     
     QDir dir(testdir);
     if (dir.exists())
         return testdir;
 
-    testdir = fontprefix + "/share/mythtv/themes/" + name;
+    testdir = gContext->GetShareDir() + "themes/" + name;
     dir.setPath(testdir);
     if (dir.exists())
         return testdir;
@@ -267,7 +262,7 @@ QString OSD::FindTheme(QString name)
 
 TTFFont *OSD::LoadFont(QString name, int size)
 {
-    QString fullname = QDir::homeDirPath() + "/.mythtv/" + name;
+    QString fullname = MythContext::GetConfDir() + "/" + name;
     TTFFont *font = new TTFFont((char *)fullname.ascii(), size, vid_width,
                                 vid_height, hmult);
 
@@ -275,7 +270,7 @@ TTFFont *OSD::LoadFont(QString name, int size)
         return font;
 
     delete font;
-    fullname = fontprefix + "/share/mythtv/" + name;
+    fullname = gContext->GetShareDir() + name;
 
     font = new TTFFont((char *)fullname.ascii(), size, vid_width,
                        vid_height, hmult);
@@ -324,7 +319,7 @@ QString OSD::getFirstText(QDomElement &element)
 void OSD::parseFont(QDomElement &element)
 {
     QString name;
-    QString fontfile = fontname;
+    QString fontfile = gContext->GetSetting("OSDFont");
     int size = -1;
     int sizeSmall = -1;
     int sizeBig = -1;    
@@ -401,6 +396,8 @@ void OSD::parseFont(QDomElement &element)
         return;
     }
 
+    QString fontSizeType = gContext->GetSetting("OSDThemeFontSizeType",
+                                                "default");
     if (fontSizeType == "small")
     {
         if (sizeSmall > 0)
@@ -1065,6 +1062,10 @@ void OSD::parseContainer(QDomElement &element)
                                    (int)(movefade.y() * hmult));
     }
 
+    QString showwith = element.attribute("showwith", "");
+    if (!showwith.isEmpty())
+        container->SetShowWith(showwith);
+
     for (QDomNode child = element.firstChild(); !child.isNull();
          child = child.nextSibling())
     {
@@ -1236,6 +1237,8 @@ void OSD::ClearAllText(const QString &name)
 void OSD::SetText(const QString &name,
                           QMap<QString, QString> &infoMap, int length)
 {
+    HideAllExcept(name);
+
     osdlock.lock();
     OSDSet *container = GetSet(name);
     if (container)
@@ -1353,6 +1356,8 @@ void OSD::StartPause(int position, bool fill, QString msgtext,
 {
     fill = fill;
 
+    HideAllExcept("status");
+
     osdlock.lock();
     OSDSet *container = GetSet("status");
     if (container)
@@ -1372,6 +1377,7 @@ void OSD::StartPause(int position, bool fill, QString msgtext,
             container->DisplayFor(displaytime * 1000000, osdFunctionalType);
         else
             container->Display();
+
         m_setsvisible = true;
         changed = true;
     }
@@ -1503,6 +1509,8 @@ void OSD::UpdateCCText(vector<ccText*> *ccbuf,
 
 void OSD::SetSettingsText(const QString &text, int length)
 {
+    HideAllExcept("settings");
+
     osdlock.lock();
     OSDSet *container = GetSet("settings");
     if (container)
@@ -1773,19 +1781,31 @@ void OSD::HideEditArrow(long long number, int type)
     osdlock.unlock();
 }
 
-void OSD::HideAll(void)
+bool OSD::HideAllExcept(const QString &other)
 {
+    bool result = false;
+
     osdlock.lock();
 
+    OSDSet *oset = GetSet(other);
+
     vector<OSDSet *>::iterator i;
     for (i = setList->begin(); i != setList->end(); i++)
-        if (*i)
-            (*i)->Hide();
-
-    runningTreeMenu = NULL;
+        if (*i && (*i)->Displaying())
+        {
+            QString name = (*i)->GetName();
+            if (name != "cc_page" && name != "menu" && name != other && 
+                (!oset || !oset->CanShowWith(name)))
+            {
+                (*i)->Hide();
+                result = true;
+            }
+        }
 
     changed = true;
     osdlock.unlock();
+
+    return result;
 }
 
 bool OSD::HideSet(const QString &name)
