@@ -21,14 +21,14 @@ using namespace std;
 #include "dialogbox.h"
 #include "mythcontext.h"
 #include "remoteutil.h"
+#include "mythdbcon.h"
 
 ProgLister::ProgLister(ProgListType pltype, const QString &view,
-                       QSqlDatabase *ldb, MythMainWindow *parent,
+                       MythMainWindow *parent,
                        const char *name)
             : MythDialog(parent, name)
 {
     type = pltype;
-    db = ldb;
     startTime = QDateTime::currentDateTime();
     searchTime = startTime;
 
@@ -53,6 +53,8 @@ ProgLister::ProgLister(ProgListType pltype, const QString &view,
     allowUpdates = true;
     updateAll = false;
     refillAll = false;
+    titleSort = false;
+    reverseSort = false;
 
     fullRect = QRect(0, 0, size().width(), size().height());
     viewRect = QRect(0, 0, 0, 0);
@@ -166,6 +168,32 @@ void ProgLister::keyPressEvent(QKeyEvent *e)
             details();
         else if (action == "TOGGLERECORD")
             quickRecord();
+        else if (action == "1")
+        {
+            if (titleSort == true)
+            {
+                titleSort = false;
+                reverseSort = false;
+            }
+            else
+            {
+                reverseSort = !reverseSort;
+            }
+            refillAll = true;
+        }
+        else if (action == "2")
+        {
+            if (titleSort == false)
+            {
+                titleSort = true;
+                reverseSort = false;
+            }
+            else
+            {
+                reverseSort = !reverseSort;
+            }
+            refillAll = true;
+        }
         else
             handled = false;
     }
@@ -271,12 +299,12 @@ void ProgLister::paintEvent(QPaintEvent *e)
     QRect r = e->rect();
     QPainter p(this);
  
-    if (updateAll || r.intersects(viewRect))
-        updateView(&p);
     if (updateAll || r.intersects(listRect))
         updateList(&p);
     if (updateAll || r.intersects(infoRect))
         updateInfo(&p);
+    if (updateAll || r.intersects(viewRect))
+        updateView(&p);
 
     updateAll = false;
 }
@@ -445,22 +473,24 @@ void ProgLister::setViewFromEdit(void)
             qphrase = viewList[oldview].utf8();
             qphrase.replace("\'", "\\\'");
 
+            MSqlQuery query(MSqlQuery::InitCon());
             querystr = QString("DELETE FROM keyword "
                                "WHERE phrase = '%1' AND searchtype = '%2';")
                                .arg(qphrase).arg(searchtype);
-            QSqlQuery query;
-            query.exec(querystr);
+            query.prepare(querystr);
+            query.exec();
         }
         if (newview < 0)
         {
             qphrase = text.utf8();
             qphrase.replace("\'", "\\\'");
 
+            MSqlQuery query(MSqlQuery::InitCon());
             querystr = QString("REPLACE INTO keyword (phrase, searchtype)"
                                "VALUES('%1','%2');")
                                .arg(qphrase).arg(searchtype);
-            QSqlQuery query;
-            query.exec(querystr);
+            query.prepare(querystr);
+            query.exec();
         }
     }
 
@@ -507,22 +537,24 @@ void ProgLister::setViewFromPowerEdit()
             qphrase = viewList[oldview].utf8();
             qphrase.replace("\'", "\\\'");
 
+            MSqlQuery query(MSqlQuery::InitCon());
             querystr = QString("DELETE FROM keyword "
                                "WHERE phrase = '%1' AND searchtype = '%2';")
                                .arg(qphrase).arg(searchtype);
-            QSqlQuery query;
-            query.exec(querystr);
+            query.prepare(querystr);
+            query.exec();
         }
         if (newview < 0)
         {
             qphrase = text.utf8();
             qphrase.replace("\'", "\\\'");
 
+            MSqlQuery query(MSqlQuery::InitCon());
             querystr = QString("REPLACE INTO keyword (phrase, searchtype)"
                                "VALUES('%1','%2');")
                                .arg(qphrase).arg(searchtype);
-            QSqlQuery query;
-            query.exec(querystr);
+            query.prepare(querystr);
+            query.exec();
         }
     }
     powerPopup->done(0);
@@ -545,7 +577,7 @@ void ProgLister::addSearchRecord(void)
     if (chooseLineEdit)
         text = chooseLineEdit->text();
     else if (chooseEditButton)
-        text = viewList[curView];
+        text = chooseListBox->currentText();
     else
         return;
 
@@ -572,9 +604,10 @@ void ProgLister::addSearchRecord(void)
 
 
     ScheduledRecording record;
-    record.loadBySearch(db, searchtype, text, what);
-    record.exec(db);
+    record.loadBySearch(searchtype, text, what);
+    record.exec();
 
+    chooseListBox->setFocus();
     setViewFromEdit();
 }
 
@@ -592,11 +625,12 @@ void ProgLister::deleteKeyword(void)
     QString qphrase = text.utf8();
     qphrase.replace("\'", "\\\'");
 
+    MSqlQuery query(MSqlQuery::InitCon());
     QString querystr = QString("DELETE FROM keyword "
                                "WHERE phrase = '%1' AND searchtype = '%2';")
                                .arg(qphrase).arg(searchtype);
-    QSqlQuery query;
-    query.exec(querystr);
+    query.prepare(querystr);
+    query.exec();
 
     chooseListBox->removeItem(view + 1);
     viewList.remove(text);
@@ -915,7 +949,7 @@ void ProgLister::powerEdit()
     powerPopup->addWidget(powerDescEdit);
 
     powerCatType = new MythComboBox(false, powerPopup);
-    powerCatType->insertItem("(Any Program Type)");
+    powerCatType->insertItem(tr("(Any Program Type)"));
     typeList.clear();
     typeList << "";
     powerCatType->insertItem(tr("Movies"));
@@ -930,14 +964,17 @@ void ProgLister::powerEdit()
     powerPopup->addWidget(powerCatType);
 
     powerCategory = new MythComboBox(false, powerPopup);
-    powerCategory->insertItem("(Any Category)");
+    powerCategory->insertItem(tr("(Any Category)"));
     categoryList.clear();
     categoryList << "";
 
+    MSqlQuery query(MSqlQuery::InitCon());
+
     QString querystr = "SELECT category FROM program GROUP BY category;";
-    QSqlQuery query;
-    query.exec(querystr);
-    if (query.isActive() && query.numRowsAffected())
+    query.prepare(querystr);
+    query.exec();
+
+    if (query.isActive() && query.size())
     {
         while (query.next())
         {
@@ -954,7 +991,7 @@ void ProgLister::powerEdit()
     powerPopup->addWidget(powerCategory);
 
     powerStation = new MythComboBox(false, powerPopup);
-    powerStation->insertItem("(Any Station)");
+    powerStation->insertItem(tr("(Any Station)"));
     stationList.clear();
     stationList << "";
 
@@ -963,16 +1000,17 @@ void ProgLister::powerEdit()
                "WHERE channel.visible = 1 "
                "GROUP BY callsign "
                "ORDER BY " + channelOrdering + ";";
-    QSqlQuery cquery;
-    cquery.exec(querystr);
-    if (cquery.isActive() && cquery.numRowsAffected())
+    query.prepare(querystr);
+    query.exec();
+
+    if (query.isActive() && query.numRowsAffected())
     {
-        while (cquery.next())
+        while (query.next())
         {
-            QString chanid = cquery.value(0).toString();
-            QString channum = cquery.value(1).toString();
-            QString chansign = QString::fromUtf8(cquery.value(2).toString());
-            QString channame = QString::fromUtf8(cquery.value(3).toString());
+            QString chanid = query.value(0).toString();
+            QString channum = query.value(1).toString();
+            QString chansign = QString::fromUtf8(query.value(2).toString());
+            QString channame = QString::fromUtf8(query.value(3).toString());
 
             QString chantext = channelFormat;
             chantext.replace("<num>", channum)
@@ -1030,7 +1068,6 @@ QString ProgLister::powerStringToSQL(QString &qphrase)
     QString str = "";
 
     qphrase.replace("\"","\\\"");
-
     QStringList field = QStringList::split( ":", qphrase, true);
 
     if ( field.count() != 6)
@@ -1040,23 +1077,43 @@ QString ProgLister::powerStringToSQL(QString &qphrase)
         return str;
     }
     if (field[0])
-        str += QString("AND program.title LIKE \"\%%1\%\" ")
+        str += QString("program.title LIKE \"\%%1\%\" ")
                        .arg(field[0]);
     if (field[1])
-        str += QString("AND program.subtitle LIKE \"\%%1\%\" ")
+    {
+        if (str > "")
+            str += "AND ";
+        str += QString("program.subtitle LIKE \"\%%1\%\" ")
                        .arg(field[1]);
+    }
     if (field[2])
-        str += QString("AND program.description LIKE \"\%%1\%\" ")
+    {
+        if (str > "")
+            str += "AND ";
+        str += QString("program.description LIKE \"\%%1\%\" ")
                        .arg(field[2]);
+    }
     if (field[3])
-        str += QString("AND program.category_type=\"%1\" ")
+    {
+        if (str > "")
+            str += "AND ";
+        str += QString("program.category_type=\"%1\" ")
                        .arg(field[3]);
+    }
     if (field[4])
-        str += QString("AND program.category=\"%1\" ")
+    {
+        if (str > "")
+            str += "AND ";
+        str += QString("program.category=\"%1\" ")
                        .arg(field[4]);
+    }
     if (field[5])
-        str += QString("AND channel.callsign=\"%1\" ")
+    {
+        if (str > "")
+            str += "AND ";
+        str += QString("channel.callsign=\"%1\" ")
                        .arg(field[5]);
+    }
     return str;
 }
 
@@ -1067,7 +1124,7 @@ void ProgLister::quickRecord()
     if (!pi)
         return;
 
-    pi->ToggleRecord(db);
+    pi->ToggleRecord();
 }
 
 void ProgLister::select()
@@ -1077,7 +1134,7 @@ void ProgLister::select()
     if (!pi)
         return;
 
-    pi->EditRecording(db);
+    pi->EditRecording();
 }
 
 void ProgLister::edit()
@@ -1087,7 +1144,7 @@ void ProgLister::edit()
     if (!pi)
         return;
 
-    pi->EditScheduled(db);
+    pi->EditScheduled();
 }
 
 void ProgLister::upcoming()
@@ -1098,7 +1155,6 @@ void ProgLister::upcoming()
         return;
 
     ProgLister *pl = new ProgLister(plTitle, pi->title,
-                                   QSqlDatabase::database(),
                                    gContext->GetMainWindow(), "proglist");
     pl->exec();
     delete pl;
@@ -1109,7 +1165,7 @@ void ProgLister::details()
     ProgramInfo *pi = itemList.at(curItem);
 
     if (pi)
-        pi->showDetails(QSqlDatabase::database());
+        pi->showDetails();
 }
 
 void ProgLister::fillViewList(const QString &view)
@@ -1119,14 +1175,16 @@ void ProgLister::fillViewList(const QString &view)
 
     if (type == plChannel) // list by channel
     {
+        MSqlQuery query(MSqlQuery::InitCon()); 
         QString querystr = "SELECT channel.chanid, channel.channum, "
             "channel.callsign, channel.name FROM channel "
             "WHERE channel.visible = 1 "
             "GROUP BY channum, callsign "
             "ORDER BY " + channelOrdering + ";";
-        QSqlQuery query;
-        query.exec(querystr);
-        if (query.isActive() && query.numRowsAffected())
+        query.prepare(querystr);
+        query.exec();
+
+        if (query.isActive() && query.size())
         {
             while (query.next())
             {
@@ -1149,10 +1207,12 @@ void ProgLister::fillViewList(const QString &view)
     }
     else if (type == plCategory) // list by category
     {
+        MSqlQuery query(MSqlQuery::InitCon()); 
         QString querystr = "SELECT category FROM program GROUP BY category;";
-        QSqlQuery query;
-        query.exec(querystr);
-        if (query.isActive() && query.numRowsAffected())
+        query.prepare(querystr);
+        query.exec();
+
+        if (query.isActive() && query.size())
         {
             while (query.next())
             {
@@ -1170,12 +1230,14 @@ void ProgLister::fillViewList(const QString &view)
     else if (type == plTitleSearch || type == plKeywordSearch ||
              type == plPeopleSearch || type == plPowerSearch)
     {
+        MSqlQuery query(MSqlQuery::InitCon()); 
         QString querystr = QString("SELECT phrase FROM keyword "
                                    "WHERE searchtype = '%1';")
                                    .arg(searchtype);
-        QSqlQuery query;
-        query.exec(querystr);
-        if (query.isActive() && query.numRowsAffected())
+        query.prepare(querystr);
+        query.exec();
+
+        if (query.isActive() && query.size())
         {
             while (query.next())
             {
@@ -1196,11 +1258,12 @@ void ProgLister::fillViewList(const QString &view)
                 QString qphrase = view.utf8();
                 qphrase.replace("\'", "\\\'");
 
+                MSqlQuery query(MSqlQuery::InitCon()); 
                 querystr = QString("REPLACE INTO keyword (phrase, searchtype)"
                                    "VALUES('%1','%2');")
                                     .arg(qphrase).arg(searchtype);
-                QSqlQuery rquery;
-                rquery.exec(querystr);
+                query.prepare(querystr);
+                query.exec();
 
                 viewList << qphrase;
                 viewTextList << qphrase;
@@ -1267,6 +1330,43 @@ void ProgLister::fillViewList(const QString &view)
         curView = viewList.count() - 1;
 }
 
+class plTitleSort
+{
+    public:
+        plTitleSort(bool reverseSort = false) {m_reverse = reverseSort;}
+
+        bool operator()(const ProgramInfo *a, const ProgramInfo *b) 
+        {
+            if (m_reverse)
+                return (a->sortTitle > b->sortTitle);
+            else
+                return (a->sortTitle < b->sortTitle);
+        }
+
+    private:
+        bool m_reverse;
+};
+
+class plTimeSort
+{
+    public:
+        plTimeSort(bool reverseSort = false) {m_reverse = reverseSort;}
+
+        bool operator()(const ProgramInfo *a, const ProgramInfo *b) 
+        {
+            if (a->startts == b->startts)
+                return (a->chanid < b->chanid);
+
+            if (m_reverse)
+                return (a->startts > b->startts);
+            else
+                return (a->startts < b->startts);
+        }
+
+    private:
+        bool m_reverse;
+};
+
 void ProgLister::fillItemList(void)
 {
     if (curView < 0)
@@ -1290,7 +1390,8 @@ void ProgLister::fillItemList(void)
                         "  oldprogram.oldtitle = program.title "
                         "WHERE channel.visible = 1 "
                         "  AND program.endtime > %1 "
-                        "  AND oldprogram.oldtitle IS NULL ")
+                        "  AND oldprogram.oldtitle IS NULL "
+                        "  AND program.manualid = 0 ")
                         .arg(startstr);
 
         if (qphrase == "movies")
@@ -1310,7 +1411,6 @@ void ProgLister::fillItemList(void)
             where += "AND (program.category_type <> 'movie' ";
             where += "OR program.airdate >= YEAR(NOW() - INTERVAL 2 YEAR)) ";
         }
-        where += "GROUP BY title ";
     }
     else if (type == plTitleSearch) // keyword search
     {
@@ -1331,26 +1431,27 @@ void ProgLister::fillItemList(void)
     }
     else if (type == plPeopleSearch) // people search
     {
-        where = QString("LEFT JOIN credits ON credits.chanid = program.chanid "
-                        "  AND credits.starttime = program.starttime "
-                        "LEFT JOIN people ON people.person = credits.person "
-                        "WHERE channel.visible = 1 "
+        where = QString(", people, credits WHERE channel.visible = 1 "
                         "  AND program.endtime > %1 "
-                        "  AND people.name LIKE '\%%2\%' ")
+                        "  AND people.name LIKE '%2' "
+                        "  AND credits.person = people.person "
+                        "  AND program.chanid = credits.chanid "
+                        "  AND program.starttime = credits.starttime")
                         .arg(startstr).arg(qphrase);
     }
     else if (type == plPowerSearch) // complex search
     {
         where = QString("WHERE channel.visible = 1 "
                         "  AND program.endtime > %1 "
-                        "  %2 ")
+                        "  AND ( %2 ) ")
                         .arg(startstr).arg(powerStringToSQL(qphrase));
     }
     else if (type == plSQLSearch) // complex search
     {
+        qphrase.remove(QRegExp("^\\s*AND\\s+", false));
         where = QString("WHERE channel.visible = 1 "
                         "  AND program.endtime > %1 "
-                        "  %2 ")
+                        "  AND ( %2 ) ")
                         .arg(startstr).arg(qphrase);
     }
     else if (type == plChannel) // list by channel
@@ -1380,10 +1481,48 @@ void ProgLister::fillItemList(void)
         where = QString("WHERE channel.visible = 1 "
                         "  AND program.starttime >= %1 ")
                         .arg(searchTime.toString("yyyyMMddhh0000"));
+        if (titleSort)
+            where += QString("  AND program.starttime < DATE_ADD(%1, "
+                             "INTERVAL 1 HOUR) ")
+                             .arg(searchTime.toString("yyyyMMddhh0000"));
     }
 
+    if (titleSort && type == plTitle)
+        where += " GROUP BY subtitle ";
+    else if (type == plNewListings || titleSort)
+        where += " GROUP BY title ";
+
     schedList.FromScheduler();
-    itemList.FromProgram(db, where, schedList);
+    itemList.FromProgram(where, schedList);
+
+    if (titleSort || reverseSort)
+    {
+        ProgramInfo *s;
+
+        vector<ProgramInfo *> sortedList;
+        while (itemList.count())
+        {
+            s = itemList.take();
+            if (type == plTitle)
+                s->sortTitle = s->subtitle;
+            else
+                s->sortTitle = s->title;
+
+            s->sortTitle.remove(QRegExp("^(The |A |An )"));
+            sortedList.push_back(s);
+        }
+
+        if (titleSort)
+            sort(sortedList.begin(), sortedList.end(),
+                 plTitleSort(reverseSort));
+        else
+            sort(sortedList.begin(), sortedList.end(),
+                 plTimeSort(reverseSort));
+
+        vector<ProgramInfo *>::iterator i = sortedList.begin();
+        for (; i != sortedList.end(); i++)
+            itemList.append(*i);
+    }
 
     if (curItem < 0 && itemList.count() > 0)
         curItem = 0;
@@ -1486,8 +1625,10 @@ void ProgLister::updateList(QPainter *p)
 
                 if (pi->recstatus == rsConflict)
                     ltype->EnableForcedFont(i, "conflicting");
-                else if (pi->recstatus <= rsWillRecord)
+                else if (pi->recstatus == rsRecording)
                     ltype->EnableForcedFont(i, "recording");
+                else if (pi->recstatus == rsWillRecord)
+                    ltype->EnableForcedFont(i, "record");
 
                 if (i + skip == curItem)
                     ltype->SetItemCurrent(i);
@@ -1531,7 +1672,7 @@ void ProgLister::updateInfo(QPainter *p)
         if (container)
         {  
             QMap<QString, QString> infoMap;
-            pi->ToMap(db, infoMap);
+            pi->ToMap(infoMap);
             container->ClearAllText();
             container->SetText(infoMap);
         }
