@@ -11,7 +11,9 @@ enum RecordingType
     kWeekslotRecord,
     kFindOneRecord,
     kOverrideRecord,
-    kDontRecord
+    kDontRecord,
+    kFindDailyRecord,
+    kFindWeeklyRecord
 };
 
 int RecTypePriority(RecordingType rectype);
@@ -20,6 +22,8 @@ enum RecordingDupInType
 {
     kDupsInRecorded     = 0x01,
     kDupsInOldRecorded  = 0x02,
+    kDupsInBoth         = 0x03,
+    kDupsNewEpi         = 0x04,
     kDupsInAll          = 0x0F
 };
 
@@ -29,8 +33,7 @@ enum RecordingDupMethodType
     kDupCheckNone     = 0x01,
     kDupCheckSub      = 0x02,
     kDupCheckDesc     = 0x04,
-    kDupCheckSubDesc  = 0x06,
-    kDupCheckNewEpi   = 0x08,
+    kDupCheckSubDesc  = 0x06
 };
 
 enum RecSearchType
@@ -39,7 +42,8 @@ enum RecSearchType
     kPowerSearch,
     kTitleSearch,
     kKeywordSearch,
-    kPeopleSearch
+    kPeopleSearch,
+    kManualSearch
 };
 
 #endif
