@@ -13,13 +13,11 @@
 #define CHECKNIT_TIMER 5000
 //#define SISCAN_DEBUG
 
-SIScan::SIScan(DVBChannel* advbchannel,QSqlDatabase *thedb, pthread_mutex_t* _db_lock, int _sourceID)
+SIScan::SIScan(DVBChannel* advbchannel, int _sourceID)
 {
     /* setup links to parents and db connections */
     chan = advbchannel;
     sourceID = _sourceID;
-    db = thedb;
-    db_lock = _db_lock;
 
     /* setup boolean values for thread */
     scannerRunning = false;
@@ -67,27 +65,25 @@ bool SIScan::ScanServicesSourceID(int SourceID)
     if (scanMode == TRANSPORT_LIST)
         return false;
 
+    MSqlQuery query(MSqlQuery::InitCon());
     /* Run DB query to get transports on sourceid SourceID connected to this card */
     QString theQuery = QString("select mplexid, sistandard, transportid from dtv_multiplex where "
                        "sourceid = %1")
                        .arg(SourceID);
+    query.prepare(theQuery);
 
-    pthread_mutex_lock(db_lock);
-    QSqlQuery query = db->exec(theQuery);
-
-    if (!query.isActive())
+    if (!query.exec() || !query.isActive())
         MythContext::DBError("Get Transports for SourceID", query);
 
-    if (query.numRowsAffected() <= 0)
+    if (query.size() <= 0)
     {
         SISCAN(QString("Unable to find any transports for sourceId %1.").arg(sourceID));
-        pthread_mutex_unlock(db_lock);
         return false;
     }
 
     scanTransports.clear();
 
-    transportsCount = transportsToScan = query.numRowsAffected();
+    transportsCount = transportsToScan = query.size();
     int tmp = transportsToScan;
     while (tmp--)
     {
@@ -100,7 +96,6 @@ bool SIScan::ScanServicesSourceID(int SourceID)
         t.FriendlyName = QString("Transport ID %1").arg(query.value(2).toString());
         scanTransports += t;
     }
-    pthread_mutex_unlock(db_lock);
 
     sourceIDTransportTuned = false;
     scanMode = TRANSPORT_LIST;    
@@ -158,6 +153,7 @@ void SIScan::StartScanner()
                 if (fAll)
                     emit ServiceScanComplete();
 */
+                emit PctServiceScanComplete(((transportsToScan-transportsCount)*100)/transportsToScan);
                 sourceIDTransportTuned = false;
             }
             else
@@ -183,12 +179,6 @@ void SIScan::StartScanner()
 
         if (scanMode == TRANSPORT_LIST)
         {
-            if (transportsCount == 0)
-            {
-                emit PctServiceScanComplete(100);
-                emit ServiceScanComplete();
-                scanMode = IDLE; 
-            }
             if ((!sourceIDTransportTuned) || ((ScanTimeout > 0) && (timer.elapsed() > ScanTimeout)))
             {
                 QValueList<TransportScanList>::Iterator i;
@@ -199,11 +189,12 @@ void SIScan::StartScanner()
                     {
                         (*i).complete = true;
                         if ((ScanTimeout > 0) && (timer.elapsed() > ScanTimeout))
-                            emit ServiceScanUpdateText("Timeout Scaning Channel");
+                            emit ServiceScanUpdateText("Timeout Scanning Channel");
                         emit ServiceScanUpdateText((*i).FriendlyName);
                         SISCAN(QString("Tuning to mplexid %1").arg((*i).mplexid));
                         transportsCount--;
-                        emit PctServiceScanComplete(((transportsToScan-transportsCount-1)*100)/transportsToScan);
+                        if (transportsCount == 0)
+                            scanMode = IDLE; 
          
                         bool result = false;                
                         if ((*i).mplexid == -1)
@@ -218,13 +209,18 @@ void SIScan::StartScanner()
                             result = chan->SetTransportByInt((*i).mplexid);
 
                         if (!result)
+                        {
+                            int pct = ((transportsToScan-transportsCount)*100)/transportsToScan;
+                            emit PctServiceScanComplete(pct);
                             emit ServiceScanUpdateText("Failed to tune");
+                            if (transportsCount == 0)
+                                emit ServiceScanComplete();
+                        }
                         else
                         {
                             if ((*i).mplexid == -1)
                             {
-                                pthread_mutex_lock(db_lock);
-                                MSqlQuery query(QString::null, db);
+                                MSqlQuery query(MSqlQuery::InitCon());
                                 query.prepare("INSERT into dtv_multiplex (frequency, "
                                                "modulation, sistandard, sourceid) "
                                                "VALUES (:FREQUENCY,:MODULATION,\"atsc\",:SOURCEID);");
@@ -242,12 +238,11 @@ void SIScan::StartScanner()
                                 if (!query.isActive())
                                     MythContext::DBError("Getting ID of new Transport.", query);
 
-                                if (query.numRowsAffected() > 0)
+                                if (query.size() > 0)
                                 {
                                     query.next();
                                     chan->SetCurrentTransportDBID(query.value(0).toInt());
                                 }
-                                pthread_mutex_unlock(db_lock);
 
                             }
                             timer.start();
@@ -306,6 +301,9 @@ bool SIScan::ATSCScanTransport(int SourceID, int FrequencyBand)
     scanTransports.clear();
 	
     /* Now generate a list of frequencies to scan and add it to the atscScanTransportList */
+
+    MSqlQuery query(MSqlQuery::InitCon());
+
     for (int x = 0 ; x < transportsToScan ; x++)
     {
         TransportScanList a;
@@ -323,20 +321,18 @@ bool SIScan::ATSCScanTransport(int SourceID, int FrequencyBand)
                            .arg(SourceID)
                            .arg(Frequency);
 
-        pthread_mutex_lock(db_lock);
-        QSqlQuery query = db->exec(theQuery);
+        query.prepare(theQuery);
     
-        if (!query.isActive())
+        if (!query.exec() || !query.isActive())
             MythContext::DBError("Check for existing transport", query);
     
-        if (query.numRowsAffected() <= 0)
+        if (query.size() <= 0)
             a.mplexid = -1;
         else
         {
             query.next();
             a.mplexid = query.value(0).toInt();            
         }
-        pthread_mutex_unlock(db_lock);
         scanTransports += a;
 
     }    
@@ -432,20 +428,20 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
     TODO: If you get a Version mismatch and you are not in setupscan mode you will want to issue a
           scan of the other transports that have the same networkID */
 
+    MSqlQuery query(MSqlQuery::InitCon());
     QString versionQuery = QString("SELECT serviceversion,sourceid FROM dtv_multiplex "
                                    "WHERE mplexid = %1")
                                    .arg(DVBTID);
-    pthread_mutex_lock(db_lock);
-    MSqlQuery query(QString::null, db);
+    query.prepare(versionQuery);
 
-    if(!query.exec(versionQuery))
+    if(!query.exec())
         MythContext::DBError("Selecting channel/dtv_multiplex", query);
 
     if (!query.isActive())
          MythContext::DBError("Check Channel full in channel/dtv_multiplex.", query);
 
 
-    if (query.numRowsAffected() > 0)
+    if (query.size() > 0)
     {
         query.next();
 
@@ -455,7 +451,6 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
         {
             SISCAN("Service table up to date for this network.");
             emit ServiceScanUpdateText("Channels up to date");
-            pthread_mutex_unlock(db_lock);
             return;
         }
         else
@@ -464,8 +459,9 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
                                    "WHERE mplexid = %2")
                                    .arg((*s).Version)
                                    .arg(DVBTID);
+            query.prepare(versionQuery);
 
-            if(!query.exec(versionQuery))
+            if(!query.exec())
                 MythContext::DBError("Selecting channel/dtv_multiplex", query);
 
             if (!query.isActive())
@@ -482,21 +478,21 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
                                "mplexid=%1 and videodevice = \"%2\"")
                                .arg(DVBTID)
                                .arg(chan->GetCardNum());
+    query.prepare(FTAQuery); 
 
-    if(!query.exec(FTAQuery))      
+    if(!query.exec())      
         MythContext::DBError("Getting FreeToAir for cardinput", query);
             
     if (!query.isActive())
         MythContext::DBError("Getting FreeToAir for cardinput", query);
 
-    if (query.numRowsAffected() > 0)
+    if (query.size() > 0)
     {
         query.next();
         FTAOnly = query.value(0).toInt();
     }
     else
     {
-        pthread_mutex_unlock(db_lock);
         return;    
     }
 
@@ -514,15 +510,16 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
                                        // Use a different style query here in the future when you are
                                        // parsing other transports..  This will work for now..
                                        .arg(chan->GetCurrentTransportDBID());
+            query.prepare(theQuery);
 
-            if(!query.exec(theQuery))
+            if(!query.exec())
                 MythContext::DBError("Selecting channel/dtv_multiplex", query);
 
             if (!query.isActive())
                 MythContext::DBError("Check Channel full in channel/dtv_multiplex.", query);
 
             // If channel not present add it
-            if (query.numRowsAffected() <= 0)
+            if (query.size() <= 0)
             {
 
                     if ((*s).ServiceName.stripWhiteSpace().isEmpty())
@@ -567,7 +564,18 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
                 }
                 else
                 {
-                    // TODO: Do an update here of the Name, etc..
+                    query.prepare("UPDATE channel set atscsrcid=:ATSCSRCID "
+                                  "WHERE serviceid=:SERVICEID and mplexid=:MPLEXID");
+                    query.bindValue(":ATSCSRCID",(*s).ATSCSourceID);
+                    query.bindValue(":SERVICEID",(*s).ServiceID);
+                    query.bindValue(":MPLEXID",chan->GetCurrentTransportDBID());
+
+                    if(!query.exec())
+                        MythContext::DBError("Updating ATSC SourceID", query);
+ 
+                    if (!query.isActive())
+                        MythContext::DBError("Updating ATSC SourceID", query);
+
                     SISCAN(QString("Channel %1 already in Database - Skipping").arg((*s).ServiceName));
                     QString status = QString("Updating %1").arg((*s).ServiceName);
                     emit ServiceScanUpdateText(status);
@@ -588,7 +596,6 @@ void SIScan::UpdateServicesInDB(QMap_SDTObject SDT)
                 emit ServiceScanUpdateText(status);
             }
     }
-    pthread_mutex_unlock(db_lock);
 
 }
 
@@ -681,8 +688,7 @@ void SIScan::UpdateTransportsInDB(NITObject NIT)
 
     for (t = NIT.Transport.begin() ; t != NIT.Transport.end() ; ++t )
     {
-        pthread_mutex_lock(db_lock);
-        MSqlQuery query(QString::null, db);
+        MSqlQuery query(MSqlQuery::InitCon());
         // See if transport already in database
         QString theQuery = QString("select * from dtv_multiplex where NetworkID = %1 and "
                    " TransportID = %2 and Frequency = %3 and sourceID = %4")
@@ -690,14 +696,16 @@ void SIScan::UpdateTransportsInDB(NITObject NIT)
                    .arg((*t).TransportID)
                    .arg((*t).Frequency)
                    .arg(sourceID);
-        if(!query.exec(theQuery))
+        query.prepare(theQuery);
+
+        if(!query.exec())
             MythContext::DBError("Selecting transports", query);
 
         if (!query.isActive())
             MythContext::DBError("Check Transport in dtv_multiplex.", query);
 
         // If transport not present add it, and move on to the next
-        if (query.numRowsAffected() <= 0)
+        if (query.size() <= 0)
         {
             emit TransportScanUpdateText(QString("Transport %1 - %2 Added")
                    .arg((*t).TransportID)
@@ -738,7 +746,6 @@ void SIScan::UpdateTransportsInDB(NITObject NIT)
                 MythContext::DBError("Inserting new transport", query);
             if (!query.isActive())
                 MythContext::DBError("Adding transport to Database.", query);
-            pthread_mutex_unlock(db_lock);
         }
         else
         {
@@ -749,7 +756,6 @@ void SIScan::UpdateTransportsInDB(NITObject NIT)
             SISCAN(QString("Transport TID = %1 NID = %2 already in Database")
                    .arg((*t).TransportID)
                    .arg((*t).NetworkID));
-            pthread_mutex_unlock(db_lock);
         }
     }
 }
@@ -765,16 +771,16 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
     // and the NetworkID/TransportID
 
     // First see if current one is NULL, if so update those values and return current mplexid
-    pthread_mutex_lock(db_lock);
 
-    MSqlQuery query(QString::null, db);
+    MSqlQuery query(MSqlQuery::InitCon());
     QString theQuery;
 
     theQuery = QString("select networkid,transportid from dtv_multiplex where "
                        "mplexid = %1")
                        .arg(CurrentMplexId);
+    query.prepare(theQuery);
 
-    if(!query.exec(theQuery))
+    if(!query.exec())
         MythContext::DBError("Getting mplexid global search", query);
 
     if (!query.isActive())
@@ -788,7 +794,6 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
 
     if ((query.value(0).toInt() == NetworkID) && (query.value(1).toInt() == TransportID))
     {
-        pthread_mutex_unlock(db_lock);
         return CurrentMplexId;
     }
 
@@ -799,14 +804,14 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
                            .arg(NetworkID)
                            .arg(TransportID)
                            .arg(CurrentMplexId);
+        query.prepare(theQuery);
 
-        if(!query.exec(theQuery))
+        if(!query.exec())
             MythContext::DBError("Getting mplexid global search", query);
 
         if (!query.isActive())
             MythContext::DBError("Getting mplexid global search", query);
 
-        pthread_mutex_unlock(db_lock);
         return CurrentMplexId;
 
     }
@@ -819,8 +824,9 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
                        .arg(NetworkID)
                        .arg(TransportID)
                        .arg(CurrentMplexId);
+    query.prepare(theQuery);
 
-    if(!query.exec(theQuery))
+    if(!query.exec())
         MythContext::DBError("Finding matching mplexid", query);
 
     if (!query.isActive())
@@ -830,24 +836,22 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
 
     // If you got an exact match just return it, since there is no question what
     // mplexid this NetworkId/TransportId is for.
-    if (query.numRowsAffected() == 1)
+    if (query.size() == 1)
     {
 #ifdef SISCAN_DEBUG
         printf("Exact Match!\n");
 #endif
         int tmp = query.value(0).toInt();
-        pthread_mutex_unlock(db_lock);
         return tmp;
     }
 
     // If you got more than 1 hit then all you can do is hope that this NetworkID/TransportID
     // pair belongs to the CurrentMplexId;
-    if (query.numRowsAffected() > 1)
+    if (query.size() > 1)
     {
 #ifdef SISCAN_DEBUG
         printf("more than 1 hit\n");
 #endif
-        pthread_mutex_unlock(db_lock);
         return CurrentMplexId;
     }
 
@@ -857,8 +861,9 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
                        "networkID = %1 and transportID = %2")
                        .arg(NetworkID)
                        .arg(TransportID);
+    query.prepare(theQuery);
 
-    if(!query.exec(theQuery))
+    if(!query.exec())
         MythContext::DBError("Getting mplexid global search", query);
 
     if (!query.isActive())
@@ -867,26 +872,23 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
     query.next();
 
     // If you still didn't find this combo return -1 (failure)
-    if (query.numRowsAffected() <= 0)
+    if (query.size() <= 0)
     {
-        pthread_mutex_unlock(db_lock);
         return -1;
     }
 
     // Now you are in trouble.. You found more than 1 match, so just guess that its the first
     // entry in the database..
-    if (query.numRowsAffected() > 1)
+    if (query.size() > 1)
     {
         SISCAN(QString("Found more than 1 match for NetworkID %1 TransportID %2")
                .arg(NetworkID).arg(TransportID));
         int tmp = query.value(0).toInt();
-        pthread_mutex_unlock(db_lock);
         return tmp;
     }
 
     // You found the entries, but it was on a different sourceID, so return that value
     int retval = query.value(0).toInt();
-    pthread_mutex_unlock(db_lock);
 
     return retval;
 
@@ -895,14 +897,14 @@ int SIScan::GetDVBTID(uint16_t NetworkID,uint16_t TransportID,int CurrentMplexId
 int SIScan::GenerateNewChanID()
 {
 
-    // This function must be called with db_lock enabled
+    MSqlQuery query(MSqlQuery::InitCon());
 
-    MSqlQuery query(QString::null, db);
+    QString theQuery =
+        QString("SELECT max(chanid) as maxchan "
+                "FROM channel WHERE sourceid=%1").arg(sourceID);
+    query.prepare(theQuery);
 
-    QString theQuery = QString("select max(chanid) as maxchan from channel where sourceid=%1")
-                       .arg(sourceID);
-
-    if(!query.exec(theQuery))
+    if(!query.exec())
         MythContext::DBError("Calculating new ChanID", query);
 
     if (!query.isActive())
@@ -911,7 +913,7 @@ int SIScan::GenerateNewChanID()
     query.next();
 
     // If transport not present add it, and move on to the next
-    if (query.numRowsAffected() <= 0)
+    if (query.size() <= 0)
         return sourceID * 1000;
 
     int MaxChanID = query.value(0).toInt();
@@ -925,7 +927,8 @@ int SIScan::GenerateNewChanID()
 
 void SIScan::AddEvents()
 {
-    MSqlQuery query(QString::null, db);
+    MSqlQuery query(MSqlQuery::InitCon());
+    MSqlQuery query2(MSqlQuery::InitCon());
     QString theQuery;
     int counter = 0;
 
@@ -962,9 +965,10 @@ void SIScan::AddEvents()
             printf("CHANID QUERY: %s\n",theQuery.ascii());
 #endif
         }
-        pthread_mutex_lock(db_lock);
 
-        if(!query.exec(theQuery))
+        query.prepare(theQuery);
+
+        if(!query.exec())
             MythContext::DBError("Looking up chanID", query);
 
         if (!query.isActive())
@@ -972,10 +976,9 @@ void SIScan::AddEvents()
 
         query.next();
 
-        if (query.numRowsAffected() <= 0)
+        if (query.size() <= 0)
         {
             SISCAN("ChanID not found so event skipped");
-            pthread_mutex_unlock(db_lock);
             events->clear();
             delete events;
             continue;
@@ -985,7 +988,6 @@ void SIScan::AddEvents()
         // Check to see if we are interseted in this channel 
         if (!query.value(1).toBool())
         {
-            pthread_mutex_unlock(db_lock);
             events->clear();
             delete events;
             continue;
@@ -996,28 +998,69 @@ void SIScan::AddEvents()
 #endif
         for (e = events->begin() ; e != events->end() ; ++e)
         {
-
-            query.prepare("select * from  program where chanid=:CHANID and "
-                      "starttime=:STARTTIME and programid=:PROGRAMID;");
+            query.prepare("select starttime, endtime, title "
+                        "from program where chanid=:CHANID and "
+                        "((starttime>=:STARTTIME and starttime<:ENDTIME) "
+                        "and not (starttime=:STARTTIME "
+                        "and endtime=:ENDTIME and title=:TITLE))");
             query.bindValue(":CHANID",ChanID);
             query.bindValue(":STARTTIME",(*e).StartTime.toString(QString("yyyy-MM-dd hh:mm:00")));
             query.bindValue(":ENDTIME",(*e).EndTime.toString(QString("yyyy-MM-dd hh:mm:00")));
-            query.bindValue(":PROGRAMID",(*e).EventID);
+            query.bindValue(":TITLE",(*e).Event_Name.utf8());
 
             if(!query.exec())
-                MythContext::DBError("Checking Event", query);
-
+                MythContext::DBError("Checking Rescheduled Event", query);
             if (!query.isActive())
-                MythContext::DBError("Checking Event", query);
+                MythContext::DBError("Checking Rescheduled Event", query);
 
-            if (query.numRowsAffected() <= 0)
+            for (query.first(); query.isValid(); query.next()) 
+            // New guide data overriding existing
+            // Possibly more than one conflict
             {
-                 counter++;
+                VERBOSE(VB_GENERAL, QString("Schedule Change on Channel %1")
+                     .arg(ChanID));
+                VERBOSE(VB_GENERAL, QString("Old: %1 %2 %3")
+                    .arg(query.value(0).toString())
+                    .arg(query.value(1).toString())
+                    .arg(query.value(2).toString()));
+                VERBOSE(VB_GENERAL, QString("New: %1 %2 %3") 
+                    .arg((*e).StartTime.toString(QString("yyyy-MM-dd hh:mm:00")))
+                    .arg((*e).EndTime.toString(QString("yyyy-MM-dd hh:mm:00")))
+                    .arg((*e).Event_Name.utf8()));
+                // Delete old EPG record.
+                query2.prepare("delete from program where chanid=:CHANID and "
+                    "starttime=:STARTTIME and endtime=:ENDTIME and title=:TITLE");
+                query2.bindValue(":CHANID",ChanID);
+                query2.bindValue(":STARTTIME",query.value(0).toString());
+                query2.bindValue(":ENDTIME",query.value(1).toString());
+                query2.bindValue(":TITLE",query.value(2).toString());
+                if(!query2.exec())
+                    MythContext::DBError("Deleting Rescheduled Event", query2);
+                if (!query2.isActive())
+                    MythContext::DBError("Deleting Rescheduled Event", query2);
+            }
 
-                 query.prepare("INSERT INTO program (chanid,starttime,endtime,"
-                          "title,description,subtitle,category,programid,"
-                          "stereo,closecaptioned,hdtv)"
-                          "VALUES (:CHANID,:STARTTIME,:ENDTIME,:TITLE,:DESCRIPTION,:SUBTITLE,:CATEGORY,:PROGRAMID,:STEREO,:CLOSECAPTIONED,:HDTV);");
+            query.prepare("select 1 from program where chanid=:CHANID and "
+                        "starttime=:STARTTIME and endtime=:ENDTIME and "
+                        "title=:TITLE");
+            query.bindValue(":CHANID",ChanID);
+            query.bindValue(":STARTTIME",(*e).StartTime.toString(QString("yyyy-MM-dd hh:mm:00")));
+            query.bindValue(":ENDTIME",(*e).EndTime.toString(QString("yyyy-MM-dd hh:mm:00")));
+            query.bindValue(":TITLE",(*e).Event_Name.utf8());
+
+            if(!query.exec())
+                MythContext::DBError("Checking If Event Exists", query);
+            if (!query.isActive())
+                MythContext::DBError("Checking If Event Exists", query);
+
+            if (query.size() <= 0)
+            {
+                counter++;
+
+                query.prepare("REPLACE INTO program (chanid,starttime,endtime,"
+                          "title,description,subtitle,category,"
+                          "stereo,closecaptioned,hdtv,airdate,originalairdate)"
+                          "VALUES (:CHANID,:STARTTIME,:ENDTIME,:TITLE,:DESCRIPTION,:SUBTITLE,:CATEGORY,:STEREO,:CLOSECAPTIONED,:HDTV,:AIRDATE,:ORIGINALAIRDATE);");
                 query.bindValue(":CHANID",ChanID);
                 query.bindValue(":STARTTIME",(*e).StartTime.toString(QString("yyyy-MM-dd hh:mm:00")));
                 query.bindValue(":ENDTIME",(*e).EndTime.toString(QString("yyyy-MM-dd hh:mm:00")));
@@ -1025,19 +1068,45 @@ void SIScan::AddEvents()
                 query.bindValue(":DESCRIPTION",(*e).Description.utf8());
                 query.bindValue(":SUBTITLE",(*e).Event_Subtitle.utf8());
                 query.bindValue(":CATEGORY",(*e).ContentDescription.utf8());
-                query.bindValue(":PROGRAMID",(*e).EventID);
                 query.bindValue(":STEREO",(*e).Stereo);
                 query.bindValue(":CLOSECAPTIONED",(*e).SubTitled);
                 query.bindValue(":HDTV",(*e).HDTV);
+                query.bindValue(":AIRDATE",(*e).Year);
+                query.bindValue(":ORIGINALAIRDATE",(*e).OriginalAirDate.toString(QString("yyyy-MM-dd")));
 
                 if(!query.exec())
                     MythContext::DBError("Adding Event", query);
 
                 if (!query.isActive())
-                   MythContext::DBError("Adding Event", query);
+                    MythContext::DBError("Adding Event", query);
+
+                for(QValueList<Person>::Iterator it=(*e).Credits.begin();it!=(*e).Credits.end();it++)
+                {
+                    query.prepare("INSERT IGNORE INTO people (name) VALUES (:NAME);");
+                    query.bindValue(":NAME",(*it).name.utf8());
+
+                    if(!query.exec())
+                        MythContext::DBError("Adding Event (People)", query);
+
+                    if (!query.isActive())
+                        MythContext::DBError("Adding Event (People)", query);
+
+                    query.prepare("INSERT INTO credits (person,chanid,starttime,"
+                        "role) SELECT person,:CHANID,:STARTTIME,:ROLE FROM "
+                        "people WHERE people.name=:NAME");
+                    query.bindValue(":CHANID",ChanID);
+                    query.bindValue(":STARTTIME",(*e).StartTime.toString(QString("yyyy-MM-dd hh:mm:00")));
+                    query.bindValue(":ROLE",(*it).role.utf8());
+                    query.bindValue(":NAME",(*it).name.utf8());
+
+                    if(!query.exec())
+                        MythContext::DBError("Adding Event (Credits)", query);
+
+                    if (!query.isActive())
+                        MythContext::DBError("Adding Event (Credits)", query);
+                }
             }
         }
-        pthread_mutex_unlock(db_lock);
 
         if (counter > 0)
         {
@@ -1051,4 +1120,3 @@ void SIScan::AddEvents()
     }
     pthread_mutex_unlock(&events_lock);
 }
-
