@@ -169,18 +169,20 @@ void VideoOutputXv::InputChanged(int width, int height, float aspect)
     {
         // Switching to custom display resolution succeeded
         // Make a note of the new size
-        dispx = dispy = 0;
-        dispw = display_res->Width();
-        disph = display_res->Height();
         w_mm =  display_res->Width_mm();
         h_mm =  display_res->Height_mm();
 
-        data->display_aspect = static_cast<float>(w_mm/h_mm);
+        data->display_aspect = display_res->GetAspectRatio();
 
-        // Resize X window to fill new resolution
-        XMoveResizeWindow(data->XJ_disp, data->XJ_win, 0, 0,
-                          display_res->Width(),
-                          display_res->Height());
+        if (!gContext->GetNumSetting("GuiSizeForTV", 0))
+        {
+            dispx = dispy = 0;
+            dispw = display_res->Width();
+            disph = display_res->Height();
+            // Resize X window to fill new resolution
+            XMoveResizeWindow(data->XJ_disp, data->XJ_win,
+                              dispx, dispy, dispw, disph);
+        }
     }
 
     MoveResize();
@@ -269,25 +271,29 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
 
     if (display_res)
     {
-        if (display_res->Width() == 0)
-        {
-            // The very first Resize needs to be the maximum possible
-            // desired res, because X will mask off anything outside
-            // the initial dimensions
-            XMoveResizeWindow(data->XJ_disp, winid, 0, 0, 1920, 1080);
-        }
+        // The very first Resize needs to be the maximum possible
+        // desired res, because X will mask off anything outside
+        // the initial dimensions
+        XMoveResizeWindow(data->XJ_disp, data->XJ_win, 0, 0,
+                          display_res->GetMaxWidth(),
+                          display_res->GetMaxHeight());
 
         if (display_res->switchToVid(width, height))
         {
             // Switching to custom display resolution succeeded
             // Make a note of the new size
-            dispw = display_res->Width();
-            disph = display_res->Height();
             w_mm = display_res->Width_mm();
             h_mm = display_res->Height_mm();
             
-            // Resize X window to fill new resolution
-            XMoveResizeWindow(data->XJ_disp, winid, 0, 0, dispw, disph);
+            if (!gContext->GetNumSetting("GuiSizeForTV", 0))
+            {
+                dispx = dispy = 0;
+                dispw = display_res->Width();
+                disph = display_res->Height();
+                // Resize X window to fill new resolution
+                XMoveResizeWindow(data->XJ_disp, data->XJ_win,
+                                  dispx, dispy, dispw, disph);
+            }
         }
     }
     else
@@ -316,8 +322,8 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
     {
         int w = DisplayWidth(data->XJ_disp, XJ_screen_num);
         int h = DisplayHeight(data->XJ_disp, XJ_screen_num);
-        int gui_w = gContext->GetNumSetting("GuiWidth", w);
-        int gui_h = gContext->GetNumSetting("GuiHeight", h);
+        int gui_w = w, gui_h = h;
+        gContext->GetResolutionSetting("Gui", gui_w,  gui_h);
 
         if (gui_w)
             w_mm = w_mm * gui_w / w;
@@ -329,6 +335,9 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
     else
         data->display_aspect = (float)w_mm/h_mm;
 
+    if (display_res)
+        data->display_aspect = display_res->GetAspectRatio();
+
     XJ_white = XWhitePixel(data->XJ_disp, XJ_screen_num);
     XJ_black = XBlackPixel(data->XJ_disp, XJ_screen_num);
 
@@ -402,14 +411,14 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
         XJ_screenwidth = display_res->Width();
         XJ_screenheight = display_res->Height();
     }
-#ifndef QWS
     else
     {
-        GetMythTVGeometry(data->XJ_disp, XJ_screen_num,
-                          &XJ_screenx, &XJ_screeny, 
-                          &XJ_screenwidth, &XJ_screenheight);
+        // Get default (possibly user selected) screen resolution from context
+        float wmult, hmult;
+
+        gContext->GetScreenSettings(XJ_screenx, XJ_screenwidth, wmult,
+                                    XJ_screeny, XJ_screenheight, hmult);
     }
-#endif
 
     old_handler = XSetErrorHandler(XJ_error_catcher);
     XSync(data->XJ_disp, 0);
@@ -819,13 +828,15 @@ void VideoOutputXv::DeleteXBuffers()
 
 void VideoOutputXv::EmbedInWidget(WId wid, int x, int y, int w, int h)
 {
+    pthread_mutex_lock(&lock);
+
     if (embedding)
     {
         MoveResize();
+        pthread_mutex_unlock(&lock);
         return;
     }
 
-    pthread_mutex_lock(&lock);
     data->XJ_curwin = wid;
 
     VideoOutput::EmbedInWidget(wid, x, y, w, h);
