@@ -30,7 +30,7 @@
 static void *SpawnLirc(void *param)
 {
     MythMainWindow *main_window = (MythMainWindow *)param;
-    QString config_file = QDir::homeDirPath() + "/.mythtv/lircrc";
+    QString config_file = MythContext::GetConfDir() + "/lircrc";
     QString program("mythtv");
     LircClient *cl = new LircClient(main_window);
     if (!cl->Init(config_file, program))
@@ -229,8 +229,6 @@ MythMainWindow::MythMainWindow()
     RegisterKey("Global", "8", "8", "8");
     RegisterKey("Global", "9", "9", "9");
 
-    qApp->setOverrideCursor(QCursor(Qt::BlankCursor));
-
     setAutoBufferSwap(false);
 
     d->drawTimer = new QTimer(this);
@@ -244,8 +242,6 @@ MythMainWindow::MythMainWindow()
 
 MythMainWindow::~MythMainWindow()
 {
-    qApp->restoreOverrideCursor();
-
     while (!d->stackList.isEmpty())
     {
         delete d->stackList.back();
@@ -352,21 +348,21 @@ void MythMainWindow::Init(void)
     setGeometry(d->xbase, d->ybase, d->screenwidth, d->screenheight);
     setFixedSize(QSize(d->screenwidth, d->screenheight));
 
-/*
-    setFont(gContext->GetMediumFont());
-    setCursor(QCursor(Qt::BlankCursor));
-*/
+    //setFont(gContext->GetMediumFont());
+
+    bool hideCursor = gContext->GetNumSetting("HideMouseCursor", 1);
+    setCursor((hideCursor) ? (Qt::BlankCursor) : (Qt::ArrowCursor));
+#ifdef QWS
+#if QT_VERSION >= 0x030300
+    QWSServer::setCursorVisible(!hideCursor);
+#endif
+#endif
+
     setGeometry(100, 100, 800, 600);
 
     if (d->painter->GetName() != "OpenGL")
         setFixedSize(QSize(800, 600));
 
-#ifdef QWS
-#if QT_VERSION >= 0x030300
-    QWSServer::setCursorVisible(false);
-#endif
-#endif
-
     WFlags flags = getWFlags();
     flags |= WRepaintNoErase;
 #ifdef QWS
