@@ -35,6 +35,7 @@ PlaybackSock::~PlaybackSock()
 
 bool PlaybackSock::SendReceiveStringList(QStringList &strlist)
 {
+    sock->Lock();
     sock->UpRef();
 
     sockLock.lock();
@@ -58,6 +59,8 @@ bool PlaybackSock::SendReceiveStringList(QStringList &strlist)
     expectingreply = false;
     sockLock.unlock();
 
+    sock->Unlock();
+
     sock->DownRef();
 
     return ok;
