@@ -18,6 +18,7 @@
 #include "libmythtv/commercial_skip.h"
 #include "libmythtv/NuppelVideoPlayer.h"
 #include "libmythtv/programinfo.h"
+#include "libmythtv/remoteutil.h"
 #include "libmyth/mythdbcon.h"
 
 using namespace std;
@@ -33,6 +34,8 @@ bool fullSpeed = true;
 bool rebuildSeekTable = false;
 bool beNice = true;
 bool inJobQueue = false;
+bool stillRecording = false;
+bool copyToCutlist = false;
 
 double fps = 29.97; 
 
@@ -46,11 +49,8 @@ void BuildVideoMarkup(QString& filename)
 
     RingBuffer *tmprbuf = new RingBuffer(filename, false);
 
-    QString name = QString("commflag%1%2").arg(getpid()).arg(rand());
 
-    MythSqlDatabase *mdb = new MythSqlDatabase(name);
-
-    if (!mdb || !mdb->isOpen())
+    if (!MSqlQuery::testDBConnection())
     {
         cerr << "Unable to open commflag db connection\n";
         delete tmprbuf;
@@ -58,7 +58,7 @@ void BuildVideoMarkup(QString& filename)
         return;
     }
 
-    NuppelVideoPlayer *nvp = new NuppelVideoPlayer(mdb, program_info);
+    NuppelVideoPlayer *nvp = new NuppelVideoPlayer(program_info);
     nvp->SetRingBuffer(tmprbuf);
 
     nvp->RebuildSeekTable(!quiet);
@@ -69,18 +69,40 @@ void BuildVideoMarkup(QString& filename)
     delete nvp;
     delete tmprbuf;
     delete program_info;
-    delete mdb;
-
 }
 
-int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
+void CopySkipListToCutList(QString chanid, QString starttime)
+{
+    QMap<long long, int> cutlist;
+    QMap<long long, int>::Iterator it;
+
+    ProgramInfo *pginfo =
+        ProgramInfo::GetProgramFromRecorded(chanid, starttime);
+
+    if (!pginfo)
+    {
+        cerr << "No program data exists for channel " <<
+            chanid.ascii() << "at " << starttime.ascii() << endl;
+        exit(-1);
+    }
+
+    pginfo->GetCommBreakList(cutlist);
+    for (it = cutlist.begin(); it != cutlist.end(); ++it)
+        if (it.data() == MARK_COMM_START)
+            cutlist[it.key()] = MARK_CUT_START;
+        else
+            cutlist[it.key()] = MARK_CUT_END;
+    pginfo->SetCutList(cutlist);
+}
+
+int FlagCommercials(QString chanid, QString starttime)
 {
     int breaksFound = 0;
     int commDetectMethod = gContext->GetNumSetting("CommercialSkipMethod",
                                                    COMM_DETECT_BLANKS);
     QMap<long long, int> blanks;
     ProgramInfo *program_info =
-        ProgramInfo::GetProgramFromRecorded(db, chanid, starttime);
+        ProgramInfo::GetProgramFromRecorded(chanid, starttime);
 
     if (!program_info)
     {
@@ -97,7 +119,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
             chanid.ascii(), starttime.ascii(), program_info->title.ascii());
         fflush( stdout );
     
-        if ((!force) && (program_info->IsCommProcessing(db)))
+        if ((!force) && (program_info->IsCommProcessing()))
         {
             printf( "IN USE\n" );
             printf( "                        "
@@ -107,7 +129,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
     }
     else
     {
-        if ((!force) && (program_info->IsCommProcessing(db)))
+        if ((!force) && (program_info->IsCommProcessing()))
             return(0);
     }
 
@@ -123,7 +145,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
     blanks.clear();
     if (showBlanks)
     {
-        program_info->GetBlankFrameList(blanks, db);
+        program_info->GetBlankFrameList(blanks);
         if (!blanks.empty())
         {
             QMap<long long, int> comms;
@@ -133,7 +155,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
 
             printf( "\n" );
 
-            program_info->GetCommBreakList(breaks, db);
+            program_info->GetCommBreakList(breaks);
             if (!breaks.empty())
             {
                 printf( "Breaks (from recordedmarkup table)\n" );
@@ -213,7 +235,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
             if (justBlanks)
             {
                 printf( "Saving new commercial break list to database.\n" );
-                program_info->SetCommBreakList(breaks, db);
+                program_info->SetCommBreakList(breaks);
             }
 
             delete commDetect;
@@ -223,7 +245,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
     }
     else if (justBlanks)
     {
-        program_info->GetBlankFrameList(blanks, db);
+        program_info->GetBlankFrameList(blanks);
         if (!blanks.empty())
         {
             QMap<long long, int> comms;
@@ -236,11 +258,11 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
             breaks.clear();
             orig_breaks.clear();
 
-            program_info->GetCommBreakList(orig_breaks, db);
+            program_info->GetCommBreakList(orig_breaks);
 
             commDetect->SetBlankFrameMap(blanks);
             commDetect->GetCommBreakMap(breaks);
-            program_info->SetCommBreakList(breaks, db);
+            program_info->SetCommBreakList(breaks);
 
             if (!quiet)
                 printf( "%d -> %d\n",
@@ -259,11 +281,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
 
     RingBuffer *tmprbuf = new RingBuffer(filename, false);
 
-    QString name = QString("commflag%1%2").arg(getpid()).arg(rand());
-
-    MythSqlDatabase *mdb = new MythSqlDatabase(name);
-
-    if (!mdb || !mdb->isOpen())
+    if (!MSqlQuery::testDBConnection())
     {
         cerr << "Unable to open commflag db connection\n";
         delete tmprbuf;
@@ -271,7 +289,7 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
         return(0);
     }
     
-    NuppelVideoPlayer *nvp = new NuppelVideoPlayer(mdb, program_info);
+    NuppelVideoPlayer *nvp = new NuppelVideoPlayer(program_info);
     nvp->SetRingBuffer(tmprbuf);
 
     if (rebuildSeekTable)
@@ -283,8 +301,19 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
     }
     else
     {
+        if (stillRecording)
+        {
+            RemoteEncoder *recorder;
+
+            nvp->SetWatchingRecording(true);
+            gContext->ConnectToMasterServer();
+
+            recorder = RemoteGetExistingRecorder(program_info);
+            if (recorder)
+                nvp->SetRecorder(recorder);
+        }
         breaksFound = nvp->FlagCommercials(showPercentage, fullSpeed,
-                                               NULL, inJobQueue);
+                                           inJobQueue);
 
         if (!quiet)
             printf( "%d\n", breaksFound );
@@ -293,7 +322,6 @@ int FlagCommercials(QSqlDatabase *db, QString chanid, QString starttime)
     delete nvp;
     delete tmprbuf;
     delete program_info;
-    delete mdb;
 
     return breaksFound;
 }
@@ -371,6 +399,10 @@ int main(int argc, char *argv[])
             if (!quiet)
                 showBlanks = true;
         }
+        else if (!strcmp(a.argv()[argpos], "--gencutlist"))
+        {
+            copyToCutlist = true;
+        }
         else if (!strcmp(a.argv()[argpos], "--justblanks"))
         {
             justBlanks = true;
@@ -379,6 +411,10 @@ int main(int argc, char *argv[])
         {
             inJobQueue = true;
         }
+        else if (!strcmp(a.argv()[argpos], "-l"))
+        {
+            stillRecording = true;
+        }
         else if (!strcmp(a.argv()[argpos], "--all"))
         {
             allRecorded = true;
@@ -416,6 +452,19 @@ int main(int argc, char *argv[])
         {
             beNice = false;
         }
+        else if (!strcmp(a.argv()[argpos],"-V"))
+        {
+            if (a.argc() > argpos)
+            {
+                QString temp = a.argv()[++argpos];
+                print_verbose_messages = temp.toInt();
+            }
+            else
+            {
+                cerr << "Missing argument to -V option\n";
+                return -1;
+            }
+        }
         else if (!strcmp(a.argv()[argpos],"-v") ||
                  !strcmp(a.argv()[argpos],"--verbose"))
         {
@@ -518,6 +567,7 @@ int main(int argc, char *argv[])
                     "--video filename             Rebuild the seektable for a video (non-recording) file" << endl <<
                     "--sleep                      Give up some CPU time after processing" << endl <<
                     "--rebuild                    Do not flag commercials, just rebuild seektable" << endl <<
+                    "--gencutlist                 Copy the commercial skip list to the cutlist" << endl <<
                     "                             each frame." << endl <<
                     "-v OR --verbose debug-level  Prints more information" << endl <<
                     "                             Accepts any combination (separated by comma)" << endl << 
@@ -554,13 +604,12 @@ int main(int argc, char *argv[])
         ++argpos;
     }
 
-    gContext = new MythContext(MYTH_BINARY_VERSION, false);
-
-    QSqlDatabase *db = QSqlDatabase::addDatabase("QMYSQL3");
-    if (!gContext->OpenDatabase(db))
+    gContext = NULL;
+    gContext = new MythContext(MYTH_BINARY_VERSION);
+    if(!gContext->Init(false))
     {
-        printf("couldn't open db\n");
-        exit(11);
+        VERBOSE(VB_IMPORTANT, "Failed to init MythContext, exiting.");
+        return -1;
     }
 
     if ((chanid.isEmpty() && !starttime.isEmpty()) ||
@@ -570,6 +619,11 @@ int main(int argc, char *argv[])
         exit(12);
     }
 
+    if (copyToCutlist) {
+        CopySkipListToCutList(chanid, starttime);
+        exit(0);
+    }
+
     if (inJobQueue) {
         int jobQueueCPU = gContext->GetNumSetting("JobQueueCPU", 0);
 
@@ -588,7 +642,7 @@ int main(int argc, char *argv[])
         testMode = false;
         showPercentage = false;
 
-        int breaksFound = FlagCommercials(db, chanid, starttime);
+        int breaksFound = FlagCommercials(chanid, starttime);
 
         delete gContext;
 
@@ -646,11 +700,11 @@ int main(int argc, char *argv[])
     }
     else if (!chanid.isEmpty() && !starttime.isEmpty())
     {
-        FlagCommercials(db, chanid, starttime);
+        FlagCommercials(chanid, starttime);
     }
     else
     {
-        QSqlQuery recordedquery;
+        MSqlQuery recordedquery(MSqlQuery::InitCon());
         QString querystr = QString("SELECT chanid, starttime "
                                     "FROM recorded "
                                     "WHERE endtime < now() "
@@ -671,12 +725,12 @@ int main(int argc, char *argv[])
 
                 if ( allRecorded )
                 {
-                    FlagCommercials(db, chanid, starttime);
+                    FlagCommercials(chanid, starttime);
                 }
                 else
                 {
                     // check to see if this show is already marked
-                    QSqlQuery markupquery;
+                    MSqlQuery markupquery(MSqlQuery::InitCon());
                     QString markupstr = QString("SELECT count(*) "
                                                 "FROM recordedmarkup "
                                                 "WHERE chanid = %1 "
@@ -692,7 +746,7 @@ int main(int argc, char *argv[])
                         if (markupquery.next())
                         {
                             if (markupquery.value(0).toInt() == 0)
-                                FlagCommercials(db, chanid, starttime);
+                                FlagCommercials(chanid, starttime);
                         }
                     }
                 }
