@@ -30,6 +30,7 @@ using namespace std;
 #include "themedmenu.h"
 #include "programinfo.h"
 #include "mythcontext.h"
+#include "mythdbcon.h"
 #include "dialogbox.h"
 #include "guidegrid.h"
 #include "mythplugin.h"
@@ -64,7 +65,6 @@ void startFinder(void)
 void startSearchTitle(void)
 {
   ProgLister searchTitle(plTitleSearch, "",
-                         QSqlDatabase::database(),
                          gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -75,7 +75,6 @@ void startSearchTitle(void)
 void startSearchKeyword(void)
 {
   ProgLister searchKeyword(plKeywordSearch, "",
-                        QSqlDatabase::database(),
                         gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -86,7 +85,6 @@ void startSearchKeyword(void)
 void startSearchPeople(void)
 {
   ProgLister searchPeople(plPeopleSearch, "",
-                         QSqlDatabase::database(),
                          gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -97,7 +95,6 @@ void startSearchPeople(void)
 void startSearchPower(void)
 {
   ProgLister searchPower(plPowerSearch, "",
-                         QSqlDatabase::database(),
                          gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -108,7 +105,6 @@ void startSearchPower(void)
 void startSearchChannel(void)
 {
     ProgLister searchChannel(plChannel, "",
-                             QSqlDatabase::database(),
                              gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -119,7 +115,6 @@ void startSearchChannel(void)
 void startSearchCategory(void)
 {
   ProgLister searchCategory(plCategory, "",
-                            QSqlDatabase::database(),
                             gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -130,7 +125,6 @@ void startSearchCategory(void)
 void startSearchMovie(void)
 {
     ProgLister searchMovie(plMovies, "",
-                           QSqlDatabase::database(),
                            gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -141,7 +135,6 @@ void startSearchMovie(void)
 void startSearchNew(void)
 {
     ProgLister searchNew(plNewListings, "",
-                         QSqlDatabase::database(),
                          gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -152,7 +145,6 @@ void startSearchNew(void)
 void startSearchTime(void)
 {
   ProgLister searchTime(plTime, "",
-                         QSqlDatabase::database(),
                          gContext->GetMainWindow(), "proglist");
 
     qApp->unlock();
@@ -162,8 +154,7 @@ void startSearchTime(void)
 
 void startManaged(void)
 {
-    QSqlDatabase *db = QSqlDatabase::database();
-    ViewScheduled vsb(db, gContext->GetMainWindow(), "view scheduled");
+    ViewScheduled vsb(gContext->GetMainWindow(), "view scheduled");
 
     qApp->unlock();
     vsb.exec();
@@ -172,8 +163,7 @@ void startManaged(void)
 
 void startProgramRecPriorities(void)
 {
-    QSqlDatabase *db = QSqlDatabase::database();
-    ProgramRecPriority rsb(db, gContext->GetMainWindow(), "recpri scheduled");
+    ProgramRecPriority rsb(gContext->GetMainWindow(), "recpri scheduled");
 
     qApp->unlock();
     rsb.exec();
@@ -182,8 +172,7 @@ void startProgramRecPriorities(void)
 
 void startChannelRecPriorities(void)
 {
-    QSqlDatabase *db = QSqlDatabase::database();
-    ChannelRecPriority rch(db, gContext->GetMainWindow(), "recpri channels");
+    ChannelRecPriority rch(gContext->GetMainWindow(), "recpri channels");
 
     qApp->unlock();
     rch.exec();
@@ -212,8 +201,7 @@ void startDelete(void)
 
 void startPrevious(void)
 {
-    PreviousBox previous( QSqlDatabase::database(), gContext->GetMainWindow(), 
-                    "previous box");
+    PreviousBox previous(gContext->GetMainWindow(), "previous box");
 
     qApp->unlock();
     previous.exec();
@@ -254,7 +242,13 @@ void startTV(void)
     QTime timer;
     timer.start();
 
-    tv->Init();
+    if (!tv->Init())
+    {
+        VERBOSE(VB_IMPORTANT, "Experienced fatal error "
+                "initializing TV class in startTV().");
+        delete tv;
+        return;
+    }
 
     bool tryTV = false;
     bool tryRecorder = false;
@@ -393,7 +387,7 @@ void TVMenuCallback(void *data, QString &selection)
     else if (sel == "settings appearance") 
     {
         AppearanceSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
 
         LanguageSettings::reload();
 
@@ -404,18 +398,18 @@ void TVMenuCallback(void *data, QString &selection)
     } 
     else if (sel == "settings recording") 
     {
-        ProfileGroupEditor editor(QSqlDatabase::database());
-        editor.exec(QSqlDatabase::database());
+        ProfileGroupEditor editor;
+        editor.exec();
     } 
     else if (sel == "settings general") 
     {
         GeneralSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
     } 
     else if (sel == "settings maingeneral") 
     {
         MainGeneralSettings mainsettings;
-        mainsettings.exec(QSqlDatabase::database());
+        mainsettings.exec();
         menu->ReloadExitKey();
         QStringList strlist = QString("REFRESH_BACKEND");
         gContext->SendReceiveStringList(strlist);
@@ -423,17 +417,17 @@ void TVMenuCallback(void *data, QString &selection)
     else if (sel == "settings playback") 
     {
         PlaybackSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
     } 
     else if (sel == "settings epg") 
     {
         EPGSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
     } 
     else if (sel == "settings generalrecpriorities") 
     {
         GeneralRecPrioritiesSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
         ScheduledRecording::signalChange(0);
     } 
     else if (sel == "settings channelrecpriorities") 
@@ -443,7 +437,7 @@ void TVMenuCallback(void *data, QString &selection)
     else if (xbox && sel == "settings xboxsettings")
     {
         XboxSettings settings;
-        settings.exec(QSqlDatabase::database());
+        settings.exec();
 
         xbox->GetSettings();
     }
@@ -522,29 +516,29 @@ int RunMenu(QString themedir)
 
 // If any settings are missing from the database, this will write
 // the default values
-void WriteDefaults(QSqlDatabase* db) 
+void WriteDefaults() 
 {
     PlaybackSettings ps;
-    ps.load(db);
-    ps.save(db);
+    ps.load();
+    ps.save();
     GeneralSettings gs;
-    gs.load(db);
-    gs.save(db);
+    gs.load();
+    gs.save();
     EPGSettings es;
-    es.load(db);
-    es.save(db);
+    es.load();
+    es.save();
     AppearanceSettings as;
-    as.load(db);
-    as.save(db);
+    as.load();
+    as.save();
     MainGeneralSettings mgs;
-    mgs.load(db);
-    mgs.save(db);
+    mgs.load();
+    mgs.save();
     GeneralRecPrioritiesSettings grs;
-    grs.load(db);
-    grs.save(db);
+    grs.load();
+    grs.save();
 }
 
-QString RandTheme(QString &themename, QSqlDatabase *db)
+QString RandTheme(QString &themename)
 {
     QDir themes(gContext->GetThemesParentDir());
     themes.setFilter(QDir::Dirs);
@@ -579,7 +573,7 @@ QString RandTheme(QString &themename, QSqlDatabase *db)
 
     ThemeSelector Theme;
     Theme.setValue(themename);
-    Theme.save(db);
+    Theme.save();
 
     return themename;
 }
@@ -592,7 +586,13 @@ int internal_play_media(const char *mrl, const char* plot, const char* title,
    
     TV *tv = new TV();
 
-    tv->Init();
+    if (!tv->Init())
+    {
+        VERBOSE(VB_IMPORTANT, "Experienced fatal error initializing "
+                "TV class in internal_play_media().");
+        delete tv;
+        return res;
+    }
 
     ProgramInfo *pginfo = new ProgramInfo();
     pginfo->recstartts = QDateTime::currentDateTime().addSecs((0 - (lenMins + 1)) * 60 );
@@ -713,6 +713,13 @@ int main(int argc, char **argv)
 {
     QString lcd_host;
     int lcd_port;
+    QString geometry = "";
+#ifdef Q_WS_X11
+    // Remember any -geometry argument which QApplication init will remove
+    for(int argpos = 1; argpos + 1 < argc; ++argpos)
+        if (!strcmp(argv[argpos],"-geometry"))
+            geometry = argv[argpos+1];
+#endif
 
 #ifdef Q_WS_MACX
     // Without this, we can't set focus to any of the CheckBoxSetting, and most
@@ -738,7 +745,7 @@ int main(int argc, char **argv)
         if (!strcmp(a.argv()[argpos],"-l") ||
             !strcmp(a.argv()[argpos],"--logfile"))
         {
-            if (a.argc() > argpos)
+            if (a.argc()-1 > argpos)
             {
                 logfile = a.argv()[argpos+1];
                 if (logfile.startsWith("-"))
@@ -751,10 +758,15 @@ int main(int argc, char **argv)
                     ++argpos;
                 }
             }
+            else
+            {
+                cerr << "Missing argument to -l/--logfile option\n";
+                return -1;
+            }
         } else if (!strcmp(a.argv()[argpos],"-v") ||
             !strcmp(a.argv()[argpos],"--verbose"))
         {
-            if (a.argc() > argpos)
+            if (a.argc()-1 > argpos)
             {
                 QString temp = a.argv()[argpos+1];
                 if (temp.startsWith("-"))
@@ -764,7 +776,7 @@ int main(int argc, char **argv)
                 } else
                 {
                     QStringList verboseOpts;
-                    verboseOpts = QStringList::split(',',a.argv()[argpos+1]);
+                    verboseOpts = QStringList::split(',', temp);
                     ++argpos;
                     for (QStringList::Iterator it = verboseOpts.begin(); 
                          it != verboseOpts.end(); ++it )
@@ -852,6 +864,26 @@ int main(int argc, char **argv)
             cout << MYTH_BINARY_VERSION << endl;
             exit(0);
         }
+        else if (!strcmp(a.argv()[argpos],"-geometry") ||
+                 !strcmp(a.argv()[argpos],"--geometry"))
+        {
+            if (a.argc()-1 > argpos)
+            {
+                geometry = a.argv()[argpos+1];
+                if (geometry.startsWith("-"))
+                {
+                    cerr << "Invalid or missing argument to -geometry option\n";
+                    return -1;
+                }
+                else
+                    ++argpos;
+            }
+            else
+            {
+                cerr << "Missing argument to -geometry option\n";
+                return -1;
+            }
+        }
         else if ((argpos + 1 == a.argc()) &&
                     !QString(a.argv()[argpos]).startsWith("-"))
         {
@@ -860,16 +892,26 @@ int main(int argc, char **argv)
         else
         {
             if (!(!strcmp(a.argv()[argpos],"-h") ||
-                !strcmp(a.argv()[argpos],"--help")))
+                !strcmp(a.argv()[argpos],"--help") ||
+                !strcmp(a.argv()[argpos],"--usage")))
                 cerr << "Invalid argument: " << a.argv()[argpos] << endl;
             cerr << "Valid options are: " << endl <<
+#ifdef Q_WS_X11
+                    "-display X-server              Create GUI on X-server, not localhost\n" <<
+#endif
+                    "-geometry or --geometry WxH    Override window size settings\n" <<
+                    "--geometry WxH+X+Y             Override window size and position\n" <<
                     "-l or --logfile filename       Writes STDERR and STDOUT messages to filename" << endl <<
                     "-v or --verbose debug-level    Prints more information" << endl <<
                     "                               Accepts any combination (separated by comma)" << endl << 
                     "                               of all,none,quiet,record,playback,channel," << endl <<
                     "                               osd,file,schedule,network,commflag,audio,libav" << endl <<
                     "--version                      Version information" << endl <<
-                    "<plugin>                       Initialize and run this plugin" << endl;
+                    "<plugin>                       Initialize and run this plugin" << endl <<
+                    endl <<
+                    "Environment Variables:" << endl <<
+                    "$MYTHTVDIR                     Set the installation prefix" << endl <<
+                    "$MYTHCONFDIR                   Set the config dir (instead of ~/.mythtv)" << endl;
             return -1;
         }
     }
@@ -901,14 +943,26 @@ int main(int argc, char **argv)
     if (signal(SIGPIPE, SIG_IGN) == SIG_ERR)
         cerr << "Unable to ignore SIGPIPE\n";
 
-    QString fileprefix = QDir::homeDirPath() + "/.mythtv";
+    QString fileprefix = MythContext::GetConfDir();
 
     QDir dir(fileprefix);
     if (!dir.exists())
         dir.mkdir(fileprefix);
 
+    gContext = NULL;
     gContext = new MythContext(MYTH_BINARY_VERSION);
-   
+
+    if (geometry != "")
+        if (!gContext->ParseGeometryOverride(geometry))
+            cerr << "Illegal -geometry argument '"
+                 << geometry <<"' (ignored)\n";
+
+    if(!gContext->Init())
+    {
+        VERBOSE(VB_IMPORTANT, "Failed to init MythContext, exiting.");
+        return -1;
+    }
+
     // Create priveleged thread, then drop privs
     pthread_t priv_thread;
 
@@ -920,19 +974,6 @@ int main(int argc, char **argv)
     }
     setuid(getuid());
 
-    QSqlDatabase *db = QSqlDatabase::addDatabase("QMYSQL3");
-    if (!db)
-    {
-        printf("Couldn't connect to database\n");
-        return -1;
-    }
-
-    if (!gContext->OpenDatabase(db))
-    {
-        printf("couldn't open db\n");
-        return -1;
-    }
-
     if (!UpgradeTVDatabaseSchema())
     {
         VERBOSE(VB_IMPORTANT,
@@ -958,13 +999,13 @@ int main(int argc, char **argv)
 
     LanguageSettings::load("mythfrontend");
 
-    WriteDefaults(db);
+    WriteDefaults();
 
     QString themename = gContext->GetSetting("Theme", "blue");
     bool randomtheme = gContext->GetNumSetting("RandomTheme", 0);
 
     if (randomtheme)
-        themename = RandTheme(themename, db);
+        themename = RandTheme(themename);
 
     QString themedir = gContext->FindThemeDir(themename);
     if (themedir == "")
