@@ -21,14 +21,13 @@ using namespace std;
 #include "scheduledrecording.h"
 #include "dialogbox.h"
 #include "mythcontext.h"
+#include "mythdbcon.h"
 #include "remoteutil.h"
 
-PreviousBox::PreviousBox(QSqlDatabase *ldb, MythMainWindow *parent,
-                       const char *name)
+PreviousBox::PreviousBox(MythMainWindow *parent, const char *name)
             : MythDialog(parent, name)
 {
     view = "";
-    db = ldb;
     startTime = QDateTime::currentDateTime();
     searchTime = startTime;
 
@@ -146,6 +145,24 @@ void PreviousBox::keyPressEvent(QKeyEvent *e)
             upcoming();
         else if (action == "DETAILS")
             details();
+        else if (action == "1")
+        {
+            if (viewList[curView] == "sort by time")
+                curView = viewList.findIndex("reverse time");
+            else
+                curView = viewList.findIndex("sort by time");
+
+            refillAll = true;
+        }
+        else if (action == "2")
+        {
+            if (viewList[curView] == "sort by title")
+                curView = viewList.findIndex("reverse title");
+            else
+                curView = viewList.findIndex("sort by title");
+
+            refillAll = true;
+        }
         else
             handled = false;
     }
@@ -348,7 +365,12 @@ void PreviousBox::select()
 
 void PreviousBox::edit()
 {
-    removalDialog();
+    ProgramInfo *pi = itemList.at(curItem);
+
+    if (!pi)
+        return;
+
+    pi->EditScheduled();
 }
 
 void PreviousBox::upcoming()
@@ -356,7 +378,6 @@ void PreviousBox::upcoming()
     ProgramInfo *pi = itemList.at(curItem);
 
     ProgLister *pl = new ProgLister(plTitle, pi->title,
-                                   QSqlDatabase::database(),
                                    gContext->GetMainWindow(), "proglist");
     pl->exec();
     delete pl;
@@ -367,7 +388,7 @@ void PreviousBox::details()
     ProgramInfo *pi = itemList.at(curItem);
 
     if (pi)
-        pi->showDetails(QSqlDatabase::database());
+        pi->showDetails();
 }
 
 void PreviousBox::fillViewList(const QString &view)
@@ -393,10 +414,10 @@ void PreviousBox::fillViewList(const QString &view)
         curView = 0;
 }
 
-class titleIDSort
+class pbTitleSort
 {
     public:
-        titleIDSort(bool reverseSort = false) {m_reverse = reverseSort;}
+        pbTitleSort(bool reverseSort = false) {m_reverse = reverseSort;}
 
         bool operator()(const ProgramInfo *a, const ProgramInfo *b) 
         {
@@ -417,10 +438,10 @@ class titleIDSort
         bool m_reverse;
 };
 
-class timeSort
+class pbTimeSort
 {
     public:
-        timeSort(bool reverseSort = false) {m_reverse = reverseSort;}
+        pbTimeSort(bool reverseSort = false) {m_reverse = reverseSort;}
 
         bool operator()(const ProgramInfo *a, const ProgramInfo *b) 
         {
@@ -440,7 +461,7 @@ void PreviousBox::fillItemList(void)
         return;
 
     ProgramInfo *s;
-    itemList.FromOldRecorded(db, "");
+    itemList.FromOldRecorded("");
 
     vector<ProgramInfo *> sortedList;
     while (itemList.count())
@@ -452,13 +473,13 @@ void PreviousBox::fillItemList(void)
     }
 
     if (viewList[curView] == "reverse time")
-        sort(sortedList.begin(), sortedList.end(), timeSort(true));
+        sort(sortedList.begin(), sortedList.end(), pbTimeSort(true));
     else if (viewList[curView] == "sort by time")
-        sort(sortedList.begin(), sortedList.end(), timeSort(false));
+        sort(sortedList.begin(), sortedList.end(), pbTimeSort(false));
     else if (viewList[curView] == "reverse title")
-        sort(sortedList.begin(), sortedList.end(), titleIDSort(true));
+        sort(sortedList.begin(), sortedList.end(), pbTitleSort(true));
     else
-        sort(sortedList.begin(), sortedList.end(), titleIDSort(false));
+        sort(sortedList.begin(), sortedList.end(), pbTitleSort(false));
 
     vector<ProgramInfo *>::iterator i = sortedList.begin();
     for (; i != sortedList.end(); i++)
@@ -595,7 +616,7 @@ void PreviousBox::updateInfo(QPainter *p)
         if (container)
         {  
             QMap<QString, QString> infoMap;
-            pi->ToMap(db, infoMap);
+            pi->ToMap(infoMap);
             container->ClearAllText();
             container->SetText(infoMap);
         }
@@ -654,22 +675,22 @@ void PreviousBox::removalDialog()
 
     if (ret == rm_episode)
     {
-        QString thequery;
-        thequery = QString("DELETE FROM oldrecorded "
-                           "WHERE chanid = '%1' AND starttime = '%2'")
-                           .arg(pi->chanid)
-                           .arg(pi->startts.toString(Qt::ISODate));
-        db->exec(thequery);
+        MSqlQuery query(MSqlQuery::InitCon());
+        query.prepare("DELETE FROM oldrecorded "
+                      "WHERE chanid = :CHANID AND starttime = :STARTTIME ;");
+        query.bindValue(":CHANID", pi->chanid);
+        query.bindValue(":STARTTIME", pi->startts.toString(Qt::ISODate));
+        query.exec();
         ScheduledRecording::signalChange(0);
         fillItemList();
     }
     else if (ret == rm_title)
     {
-        QString thequery;
-        thequery = QString("DELETE FROM oldrecorded "
-                           "WHERE title = \"%1\"")
-                           .arg(pi->title);
-        db->exec(thequery.utf8());
+        MSqlQuery query(MSqlQuery::InitCon());
+        query.prepare("DELETE FROM oldrecorded WHERE title = :TITLE ;");
+        query.bindValue(":TITLE", pi->title.utf8());
+        query.exec();
+
         ScheduledRecording::signalChange(0);
         fillItemList();
     }
