@@ -14,11 +14,10 @@ using namespace std;
 #include "programinfo.h"
 #include "jobqueue.h"
 #include "mythcontext.h"
+#include "mythdbcon.h"
 #include "transcode.h"
 #include "mpeg2trans.h"
 
-QSqlDatabase *db;
-
 void StoreTranscodeState(ProgramInfo *pginfo, int status, bool useCutlist);
 void UpdatePositionMap(QMap <long long, long long> &posMap, QString mapfile,
                        ProgramInfo *pginfo);
@@ -50,6 +49,7 @@ void usage(char *progname)
 
 int main(int argc, char *argv[])
 {
+    QString verboseString = QString("");
     QString chanid, starttime, infile;
     QString profilename = QString("autodetect");
     QString fifodir = NULL;
@@ -61,8 +61,16 @@ int main(int argc, char *argv[])
 
     QApplication a(argc, argv, false);
 
+    print_verbose_messages = VB_NONE;
+
     //  Load the context
-    gContext = new MythContext(MYTH_BINARY_VERSION,false);
+    gContext = NULL;
+    gContext = new MythContext(MYTH_BINARY_VERSION);
+    if(!gContext->Init(false))
+    {
+        VERBOSE(VB_IMPORTANT, "Failed to init MythContext, exiting.");
+        return -1;
+    }
 
     int found_starttime = 0;
     int found_chanid = 0;
@@ -117,7 +125,112 @@ int main(int argc, char *argv[])
                 usage(a.argv()[0]);
                 return -1;
             }
-        } 
+        }
+        else if (!strcmp(a.argv()[argpos],"-V"))
+        {
+            if (a.argc() > argpos)
+            {
+                QString temp = a.argv()[++argpos];
+                print_verbose_messages = temp.toInt();
+            }
+            else
+            {
+                cerr << "Missing argument to -V option\n";
+                return -1;
+            }
+        }
+        else if (!strcmp(a.argv()[argpos],"-v") ||
+                 !strcmp(a.argv()[argpos],"--verbose"))
+        {
+            if (a.argc() > argpos)
+            {
+                QString temp = a.argv()[argpos+1];
+                if (temp.startsWith("-"))
+                {
+                    cerr << "Invalid or missing argument to -v/--verbose option\n";
+                    return -1;
+                }
+                else
+                {
+                    QStringList verboseOpts;
+                    verboseOpts = QStringList::split(',',a.argv()[argpos+1]);
+                    ++argpos;
+                    for (QStringList::Iterator it = verboseOpts.begin(); 
+                         it != verboseOpts.end(); ++it )
+                    {
+                        if (!strcmp(*it,"none"))
+                        {
+                            print_verbose_messages = VB_NONE;
+                            verboseString = "";
+                        }
+                        else if (!strcmp(*it,"all"))
+                        {
+                            print_verbose_messages = VB_ALL;
+                            verboseString = "all";
+                        }
+                        else if (!strcmp(*it,"quiet"))
+                        {
+                            print_verbose_messages = VB_IMPORTANT;
+                            verboseString = "important";
+                        }
+                        else if (!strcmp(*it,"record"))
+                        {
+                            print_verbose_messages |= VB_RECORD;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"playback"))
+                        {
+                            print_verbose_messages |= VB_PLAYBACK;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"channel"))
+                        {
+                            print_verbose_messages |= VB_CHANNEL;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"osd"))
+                        {
+                            print_verbose_messages |= VB_OSD;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"file"))
+                        {
+                            print_verbose_messages |= VB_FILE;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"schedule"))
+                        {
+                            print_verbose_messages |= VB_SCHEDULE;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"network"))
+                        {
+                            print_verbose_messages |= VB_NETWORK;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"jobqueue"))
+                        {
+                            print_verbose_messages |= VB_JOBQUEUE;
+                            verboseString += " " + *it;
+                        }
+                        else if (!strcmp(*it,"commflag"))
+                        {
+                            print_verbose_messages |= VB_COMMFLAG;
+                            verboseString += " " + *it;
+                        }
+                        else
+                        {
+                            cerr << "Unknown argument for -v/--verbose: "
+                                 << *it << endl;;
+                        }
+                    }
+                }
+            } else
+            {
+                cerr << "Missing argument to -v/--verbose option\n";
+                return -1;
+            }
+        }
         else if (!strcmp(a.argv()[argpos],"-p") ||
                  !strcmp(a.argv()[argpos],"--profile")) 
         {
@@ -229,26 +342,26 @@ int main(int argc, char *argv[])
          return -1;
     }
 
-    db = QSqlDatabase::addDatabase("QMYSQL3");
-    if (!db)
-    {
-        printf("Couldn't connect to database\n");
-        return -1;
-    }
+    if (verboseString != "")
+        VERBOSE(VB_ALL, QString("Enabled verbose msgs :%1").arg(verboseString));
 
-    if (!gContext->OpenDatabase(db))
+    //if (!db)
+    //{
+    //    printf("Couldn't connect to database\n");
+    //    return -1;
+    //}
+
+    if (!MSqlQuery::testDBConnection())
     {
         printf("couldn't open db\n");
         return -1;
     }
 
-    MythContext::KickDatabase(db);
-
     ProgramInfo *pginfo = NULL;
     if (!found_infile)
     {
         QDateTime startts = QDateTime::fromString(starttime, Qt::ISODate);
-        pginfo = ProgramInfo::GetProgramFromRecorded(db, chanid, startts);
+        pginfo = ProgramInfo::GetProgramFromRecorded(chanid, startts);
 
         if (!pginfo)
         {
@@ -257,17 +370,26 @@ int main(int argc, char *argv[])
             return -1;
         }
 
-        QString fileprefix = gContext->GetFilePrefix();
-        infile = pginfo->GetRecordFilename(fileprefix);
+        infile = pginfo->GetPlaybackURL();
     }
-    QString tmpfile = infile + ".tmp";
+
+    QString tmpfile;
+    if (infile.left(7) == "myth://") {
+        VERBOSE(VB_IMPORTANT, QString("Attempted to transcode %1. "
+               "Mythtranscode is currently unable to transcode remote "
+               "files.")
+               .arg(infile));
+        exit(0);
+    }
+
+    tmpfile = infile + ".tmp";
 
     int jobID = -1;
     if (use_db)
     {
-        jobID = JobQueue::GetJobID(db, JOB_TRANSCODE, pginfo->chanid,
+        jobID = JobQueue::GetJobID(JOB_TRANSCODE, pginfo->chanid,
                                    pginfo->startts);
-        JobQueue::ChangeJobStatus(db, jobID, JOB_RUNNING);
+        JobQueue::ChangeJobStatus(jobID, JOB_RUNNING);
     }
 
     if (found_infile)
@@ -278,7 +400,7 @@ int main(int argc, char *argv[])
         UpdatePositionMap(posMap, tmpfile + ".map", NULL);
         exit(0);
     }
-    Transcode *transcode = new Transcode(db, pginfo);
+    Transcode *transcode = new Transcode(pginfo);
 
     VERBOSE(VB_GENERAL, QString("Transcoding from %1 to %2")
                         .arg(infile).arg(tmpfile));
@@ -295,7 +417,7 @@ int main(int argc, char *argv[])
     if (result == REENCODE_MPEG2TRANS)
     {
         if (useCutlist)
-            pginfo->GetCutList(deleteMap, db);
+            pginfo->GetCutList(deleteMap);
         MPEG2trans *mpeg2trans = new MPEG2trans(&deleteMap);
         if (build_index)
         {
@@ -315,14 +437,14 @@ int main(int argc, char *argv[])
     if (result == REENCODE_OK)
     {
         if (use_db)
-            JobQueue::ChangeJobStatus(db, jobID, JOB_STOPPING);
+            JobQueue::ChangeJobStatus(jobID, JOB_STOPPING);
         VERBOSE(VB_GENERAL, QString("Transcoding %1 done").arg(infile));
         retval = 0;
     } 
     else if (result == REENCODE_CUTLIST_CHANGE)
     {
         if (use_db)
-            JobQueue::ChangeJobStatus(db, jobID, JOB_RETRY);
+            JobQueue::ChangeJobStatus(jobID, JOB_RETRY);
         VERBOSE(VB_GENERAL, QString("Transcoding %1 aborted because of "
                                     "cutlist update").arg(infile));
         retval = 1;
@@ -330,7 +452,7 @@ int main(int argc, char *argv[])
     else if (result == REENCODE_STOPPED)
     {
         if (use_db)
-            JobQueue::ChangeJobStatus(db, jobID, JOB_ABORTING);
+            JobQueue::ChangeJobStatus(jobID, JOB_ABORTING);
         VERBOSE(VB_GENERAL, QString("Transcoding %1 stopped because of "
                                     "stop command").arg(infile));
         retval = 1;
@@ -338,7 +460,7 @@ int main(int argc, char *argv[])
     else
     {
         if (use_db)
-            JobQueue::ChangeJobStatus(db, jobID, JOB_ERRORING);
+            JobQueue::ChangeJobStatus(jobID, JOB_ERRORING);
         VERBOSE(VB_GENERAL, QString("Transcoding %1 failed").arg(infile));
         retval = -1;
     }
@@ -353,7 +475,7 @@ void UpdatePositionMap(QMap <long long, long long> &posMap, QString mapfile,
 {
     if (pginfo)
     {
-        pginfo->SetPositionMap(posMap, MARK_GOP_BYFRAME, db);
+        pginfo->SetPositionMap(posMap, MARK_GOP_BYFRAME);
     }
     else if (mapfile)
     {
