@@ -21,6 +21,10 @@ using namespace std;
 #include "mythcontext.h"
 #include "jobqueue.h"
 
+extern "C" {
+#include "../libavcodec/avcodec.h"
+}
+
 // This class is to act as a fake audio output device to store the data
 // for reencoding.
 
@@ -184,7 +188,10 @@ class AudioReencodeBuffer : public AudioOutput
         // Do nothing
         return MUTE_OFF;
     }
-    
+
+    //  These are pure virtual in AudioOutput, but we don't need them here
+    virtual void bufferOutputData(bool){ return; }
+    virtual int readOutputData(unsigned char*, int ){ return 0; }
 
     int bufsize;
     unsigned char *audiobuffer;
@@ -192,13 +199,9 @@ class AudioReencodeBuffer : public AudioOutput
     long long last_audiotime;
 };
 
-Transcode::Transcode(QSqlDatabase *db, ProgramInfo *pginfo)
+Transcode::Transcode(ProgramInfo *pginfo)
 {
-    QString dbname = QString("transcode%1%2").arg(getpid()).arg(rand());
-    nvpdb = new MythSqlDatabase(dbname);
-
     m_proginfo = pginfo;
-    m_db = db;
     nvr = NULL;
     nvp = NULL;
     inRingBuffer = NULL;
@@ -228,8 +231,6 @@ Transcode::~Transcode()
         }
         delete kfa_table;
     }
-    if (nvpdb)
-        delete nvpdb;
 }
 void Transcode::ReencoderAddKFA(long curframe, long lastkey, long num_keyframes)
 {
@@ -249,9 +250,9 @@ bool Transcode::GetProfile(QString profileName, QString encodingType)
     {
         bool result = false;
         if (encodingType == "MPEG-2")
-            result = profile.loadByGroup(m_db, "MPEG2", "Transcoders");
+            result = profile.loadByGroup("MPEG2", "Transcoders");
         if (encodingType == "MPEG-4" || encodingType == "RTjpeg")
-            result = profile.loadByGroup(m_db, "RTjpeg/MPEG4",
+            result = profile.loadByGroup("RTjpeg/MPEG4",
                                          "Transcoders");
         if (! result)
         {
@@ -269,7 +270,7 @@ bool Transcode::GetProfile(QString profileName, QString encodingType)
         profileID = profileName.toInt(&isNum);
         // If a bad profile is specified, there will be trouble
         if (isNum && profileID > 0)
-            profile.loadByID(m_db, profileID);
+            profile.loadByID(profileID);
         else
         {
             VERBOSE(VB_IMPORTANT, QString("Couldn't find profile #: %1").
@@ -302,26 +303,32 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     int jobID = -1;
     if (chkTranscodeDB)
     {
-        jobID = JobQueue::GetJobID(m_db, JOB_TRANSCODE, m_proginfo->chanid,
+        jobID = JobQueue::GetJobID(JOB_TRANSCODE, m_proginfo->chanid,
                                    m_proginfo->startts);
 
         if (jobID < 0)
+        {
+            VERBOSE(VB_IMPORTANT, "ERROR, Transcode called from JobQueue but "
+                                  "no jobID found!");
             return REENCODE_ERROR;
+        }
 
-        JobQueue::ChangeJobComment(m_db, jobID,
-                                   "0% " + QObject::tr("Completed"));
+        JobQueue::ChangeJobComment(jobID, "0% " + QObject::tr("Completed"));
     }
 
-    nvp = new NuppelVideoPlayer(nvpdb, m_proginfo);
+    nvp = new NuppelVideoPlayer(m_proginfo);
     nvp->SetNoVideo();
 
     QDateTime curtime = QDateTime::currentDateTime();
     QDateTime statustime = curtime;
     if (honorCutList && m_proginfo)
     {
-        if (m_proginfo->IsEditing(m_db) || m_proginfo->IsCommProcessing(m_db))
+        if (m_proginfo->IsEditing() || m_proginfo->IsCommProcessing())
+        {
+            VERBOSE(VB_IMPORTANT, "Transcoding aborted, cutlist changed");
             return REENCODE_CUTLIST_CHANGE;
-        m_proginfo->SetMarkupFlag(MARK_UPDATED_CUT, false, m_db);
+        }
+        m_proginfo->SetMarkupFlag(MARK_UPDATED_CUT, false);
         curtime = curtime.addSecs(60);
     }
 
@@ -337,9 +344,13 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     AudioOutput *audioOutput = new AudioReencodeBuffer(0, 0);
     AudioReencodeBuffer *arb = ((AudioReencodeBuffer*)audioOutput);
     nvp->SetAudioOutput(audioOutput);
+    nvp->SetTranscoding(true);
 
     if (nvp->OpenFile(false) < 0)
+    {
+        VERBOSE(VB_IMPORTANT, "Transcoding aborted, error opening file.");
         return REENCODE_ERROR;
+    }
 
     nvp->ReinitAudio();
     QString encodingType = nvp->GetEncodingType();
@@ -349,26 +360,40 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
 
     int video_width = nvp->GetVideoWidth();
     int video_height = nvp->GetVideoHeight();
+    float video_aspect = nvp->GetVideoAspect();
     float video_frame_rate = nvp->GetFrameRate();
     long long total_frame_count = nvp->GetTotalFrameCount();
+    int newWidth = video_width;
+    int newHeight = video_height;
 
     kfa_table = new QPtrList<struct kfatable_entry>;
 
     if (fifodir == NULL)
     {
         if (!GetProfile(profileName, encodingType)) {
+            VERBOSE(VB_IMPORTANT, "Transcoding aborted, no profile found.");
             return REENCODE_ERROR;
         }
         vidsetting = profile.byName("videocodec")->getValue();
         if (vidsetting == "MPEG-2")
+        {
+            VERBOSE(VB_IMPORTANT, "Transcoding aborted, need MPEG-2.");
             return REENCODE_MPEG2TRANS;
+        }
+
         // Recorder setup
-        nvr->SetFrameRate(video_frame_rate);
 
         // this is ripped from tv_rec SetupRecording. It'd be nice to merge
         nvr->SetOption("inpixfmt", FMT_YV12);
-        nvr->SetOption("width", video_width);
-        nvr->SetOption("height", video_height);
+
+        if (profile.byName("transcoderesize")->getValue().toInt())
+        {
+            newWidth = profile.byName("width")->getValue().toInt();
+            newHeight = profile.byName("height")->getValue().toInt();
+        }
+
+        nvr->SetOption("width", newWidth);
+        nvr->SetOption("height", newHeight);
 
         nvr->SetOption("tvformat", gContext->GetSetting("TVFormat"));
         nvr->SetOption("vbiformat", gContext->GetSetting("VbiFormat"));
@@ -419,6 +444,10 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
 
         nvr->AudioInit(true);
 
+        nvr->SetFrameRate(video_frame_rate);
+        nvr->SetVideoAspect(video_aspect);
+        nvr->SetTranscoding(true);
+
         outRingBuffer = new RingBuffer(outputname, true, false);
         nvr->SetRingBuffer(outRingBuffer);
         nvr->WriteHeader();
@@ -426,7 +455,8 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     }
 
     if (vidsetting == encodingType && !framecontrol &&
-        fifodir == NULL && honorCutList)
+        fifodir == NULL && honorCutList &&
+        video_width == newWidth && video_height == newHeight)
     {
         copyvideo = true;
         VERBOSE(VB_GENERAL, "Reencoding video in 'raw' mode");
@@ -443,9 +473,9 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
 
     VideoFrame frame;
     frame.codec = FMT_YV12;
-    frame.width = video_width;
-    frame.height = video_height;
-    frame.size = video_width * video_height * 3 / 2;
+    frame.width = newWidth;
+    frame.height = newHeight;
+    frame.size = newWidth * newHeight * 3 / 2;
 
     if (fifodir != NULL)
     {
@@ -486,6 +516,7 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     long totalAudio = 0;
     int dropvideo = 0;
     long long lasttimecode = 0;
+    long long timecodeOffset = 0;
 
     float rateTimeConv = arb->eff_audiorate * arb->bytes_per_sample / 1000.0;
     float vidFrameTime = 1000.0 / video_frame_rate;
@@ -493,6 +524,17 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     VideoOutput *videoOutput = nvp->getVideoOutput();
     bool is_key = 0;
     bool first_loop = true;
+    unsigned char *newFrame = new unsigned char[newWidth * newHeight * 3 / 2];
+
+    frame.buf = newFrame;
+    AVPicture imageIn, imageOut;
+    ImgReSampleContext *scontext;
+
+    if (video_width != newWidth || video_height != newHeight)
+        VERBOSE(VB_GENERAL, QString("Resizing video from %1x%2 to %3x%4")
+                                    .arg(video_width).arg(video_height)
+                                    .arg(newWidth).arg(newHeight));
+
     while (nvp->TranscodeGetNextFrame(dm_iter, &did_ff, &is_key, honorCutList))
     {
         if (first_loop)
@@ -501,15 +543,15 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
             first_loop = false;
         }
         VideoFrame *lastDecode = videoOutput->GetLastDecodedFrame();
-        frame.buf = lastDecode->buf;
+
         frame.timecode = lastDecode->timecode;
 
         if (frame.timecode < lasttimecode)
             frame.timecode = (long long)(lasttimecode + vidFrameTime);
-        lasttimecode = frame.timecode;
 
         if (fifow)
         {
+            frame.buf = lastDecode->buf;
             totalAudio += arb->audiobuffer_len;
             int audbufTime = (int)(totalAudio / rateTimeConv);
             int auddelta = arb->last_audiotime - audbufTime;
@@ -583,6 +625,7 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
             videoOutput->DoneDisplayingFrame();
             audioOutput->Reset();
             nvp->FlushTxtBuffers();
+            lasttimecode = frame.timecode;
         }
         else if (copyaudio)
         {
@@ -592,6 +635,9 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
             {
                 // The Raw state changed during decode.  This is not good
                 unlink(outputname);
+                delete newFrame;
+                VERBOSE(VB_IMPORTANT, "Transcoding aborted, NuppelVideoPlayer "
+                                      "is not in raw audio mode.");
                 return REENCODE_ERROR;
             }
 
@@ -620,7 +666,16 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
                 }
             }
 
-            if (! nvp->WriteStoredData(outRingBuffer, (did_ff == 0)))
+            if (did_ff == 1)
+            {
+                timecodeOffset +=
+                    (frame.timecode - lasttimecode - (int)vidFrameTime);
+            }
+            lasttimecode = frame.timecode;
+            frame.timecode -= timecodeOffset;
+
+            if (! nvp->WriteStoredData(outRingBuffer, (did_ff == 0),
+                                       timecodeOffset))
             {
                 if (did_ff == 1)
                 {
@@ -628,6 +683,23 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
                   did_ff = 2;
                   writekeyframe = true;
                 }
+
+                if ((video_width == newWidth) && (video_height == newHeight))
+                {
+                    frame.buf = lastDecode->buf;
+                }
+                else
+                {
+                    avpicture_fill(&imageIn, lastDecode->buf, PIX_FMT_YUV420P,
+                                   video_width, video_height);
+                    avpicture_fill(&imageOut, frame.buf, PIX_FMT_YUV420P,
+                                   newWidth, newHeight);
+                    scontext = img_resample_init(newWidth, newHeight,
+                                                 video_width, video_height);
+                    img_resample(scontext, &imageOut, &imageIn);
+                    img_resample_close(scontext);
+                }
+
                 nvr->WriteVideo(&frame, true, writekeyframe);
             }
             audioOutput->Reset();
@@ -635,22 +707,50 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
         } 
         else 
         {
+            if (did_ff == 1)
+            {
+                did_ff = 2;
+                timecodeOffset +=
+                    (frame.timecode - lasttimecode - (int)vidFrameTime);
+            }
+
+            if ((video_width == newWidth) && (video_height == newHeight))
+            {
+                frame.buf = lastDecode->buf;
+            }
+            else
+            {
+                avpicture_fill(&imageIn, lastDecode->buf, PIX_FMT_YUV420P,
+                               video_width, video_height);
+                avpicture_fill(&imageOut, frame.buf, PIX_FMT_YUV420P,
+                               newWidth, newHeight);
+                scontext = img_resample_init(newWidth, newHeight,
+                                             video_width, video_height);
+                img_resample(scontext, &imageOut, &imageIn);
+                img_resample_close(scontext);
+            }
+
             // audio is fully decoded, so we need to reencode it
             audioframesize = arb->audiobuffer_len;
             if (audioframesize > 0)
             {
                 nvr->SetOption("audioframesize", audioframesize);
                 int starttime = audioOutput->GetAudiotime();
-                nvr->WriteAudio(arb->audiobuffer, audioFrame++, starttime);
+                nvr->WriteAudio(arb->audiobuffer, audioFrame++,
+                                starttime - timecodeOffset);
                 if (nvr->IsErrored()) {
                     VERBOSE(VB_IMPORTANT, "Transcode: Encountered "
                             "irrecoverable error in NVR::WriteAudio");
+                    delete newFrame;
                     return REENCODE_ERROR;
                 }
                 arb->audiobuffer_len = 0;
             }
             nvp->TranscodeWriteText(&TranscodeWriteText, (void *)(nvr));
 
+            lasttimecode = frame.timecode;
+            frame.timecode -= timecodeOffset;
+
             if (forceKeyFrames)
                 nvr->WriteVideo(&frame, true, true);
             else
@@ -667,21 +767,25 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
         if (QDateTime::currentDateTime() > curtime) 
         {
             if (honorCutList && 
-                m_proginfo->CheckMarkupFlag(MARK_UPDATED_CUT, m_db)) 
+                m_proginfo->CheckMarkupFlag(MARK_UPDATED_CUT))
             {
                 unlink(outputname);
+                delete newFrame;
+                VERBOSE(VB_IMPORTANT, "Transcoding aborted, cutlist updated");
                 return REENCODE_CUTLIST_CHANGE;
             }
 
             if (chkTranscodeDB)
             {
-                if (JobQueue::GetJobCmd(m_db, jobID) == JOB_STOP)
+                if (JobQueue::GetJobCmd(jobID) == JOB_STOP)
                 {
                     unlink(outputname);
+                    delete newFrame;
+                    VERBOSE(VB_IMPORTANT, "Transcoding STOPped by JobQueue");
                     return REENCODE_STOPPED;
                 }
                 int percentage = curFrameNum * 100 / total_frame_count;
-                JobQueue::ChangeJobComment(m_db, jobID,
+                JobQueue::ChangeJobComment(jobID,
                                            QString("%1% ").arg(percentage) + 
                                            QObject::tr("Completed"));
             }
@@ -701,6 +805,7 @@ int Transcode::TranscodeFile(char *inputname, char *outputname,
     } else {
         fifow->FIFODrain();
     }
+    delete newFrame;
     return REENCODE_OK;
 }
 
